from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Dict, Optional
import re

@dataclass
class AccentChar:
    char: str  # Single character string
    accent: str


@dataclass
class SpecialFontChar:
    letter: str  # UppercaseLetter or specific LaTeX commands
    font_cmd: str  # LaTeX font command


class UTF8ToLtXConverter(ABC):
    @abstractmethod
    def convert(self, char: str) -> str:
        pass


class HashUTF8ToLtXConverter(UTF8ToLtXConverter):
    def convert(self, char: str) -> str:
        is_alphanumeric = re.match(r'[a-z0-9]', char, re.IGNORECASE)
        if is_alphanumeric:
            return char

        accent_char = vowels_with_accents.get(char)
        if accent_char:
            ltx_cmd = self.convert_accent_char_to_ltx(accent_char)
            if ltx_cmd:
                return ltx_cmd
            return char

        special_char = self.convert_special_char_to_ltx(char)
        if special_char:
            return special_char

        return char

    def convert_accent_char_to_ltx(self, accent_char: AccentChar) -> Optional[str]:
        cmd = accent_to_ltx_cmd.get(accent_char.accent)
        if not cmd:
            return None
        return f"\\{cmd}{{{accent_char.char}}}"

    def convert_special_char_to_ltx(self, char: str) -> Optional[str]:
        special_font_char = special_font_chars.get(char)
        if not special_font_char:
            return None
        return f"\\{special_font_char.font_cmd}{{{special_font_char.letter}}}"


vowels_with_accents: Dict[str, AccentChar] = {
    'á': AccentChar(char='a', accent='´'),
    'à': AccentChar(char='a', accent='`'),
    'â': AccentChar(char='a', accent='^'),
    'ã': AccentChar(char='a', accent='~'),
    'ä': AccentChar(char='a', accent='¨'),
    'å': AccentChar(char='a', accent='˚'),
    'ą': AccentChar(char='a', accent='˙'),
    'ă': AccentChar(char='a', accent='˘'),
    'ǎ': AccentChar(char='a', accent='ˇ'),
    'ǟ': AccentChar(char='a', accent='ˆ'),
    'ǻ': AccentChar(char='a', accent='˙'),
    'ǡ': AccentChar(char='a', accent='-'),
    'ā': AccentChar(char='a', accent='-'),
    'é': AccentChar(char='e', accent='´'),
    'è': AccentChar(char='e', accent='`'),
    'ê': AccentChar(char='e', accent='^'),
    'ë': AccentChar(char='e', accent='¨'),
    'ę': AccentChar(char='e', accent='˙'),
    'ě': AccentChar(char='e', accent='ˇ'),
    'ȇ': AccentChar(char='i', accent='^'),
    'ё': AccentChar(char='e', accent='¨'),
    'ē': AccentChar(char='e', accent='-'),
    'í': AccentChar(char='i', accent='´'),
    'ì': AccentChar(char='i', accent='`'),
    'î': AccentChar(char='i', accent='^'),
    'ï': AccentChar(char='i', accent='¨'),
    'į': AccentChar(char='i', accent='˙'),
    'ǐ': AccentChar(char='i', accent='ˇ'),
    'ȉ': AccentChar(char='i', accent='`'),
    'ȋ': AccentChar(char='i', accent='¨'),
    'ī': AccentChar(char='i', accent='-'),
    'ó': AccentChar(char='o', accent='´'),
    'ò': AccentChar(char='o', accent='`'),
    'ô': AccentChar(char='o', accent='^'),
    'õ': AccentChar(char='o', accent='~'),
    'ö': AccentChar(char='o', accent='¨'),
    'ő': AccentChar(char='o', accent='˝'),
    'ǒ': AccentChar(char='o', accent='ˇ'),
    'ȍ': AccentChar(char='o', accent='`'),
    'ȏ': AccentChar(char='o', accent='¨'),
    'ȫ': AccentChar(char='o', accent='˘'),
    'ȭ': AccentChar(char='o', accent='˝'),
    'ȯ': AccentChar(char='o', accent='˙'),
    'ō': AccentChar(char='o', accent='-'),
    'ú': AccentChar(char='u', accent='´'),
    'ù': AccentChar(char='u', accent='`'),
    'û': AccentChar(char='u', accent='^'),
    'ü': AccentChar(char='u', accent='¨'),
    'ű': AccentChar(char='u', accent='˝'),
    'ǔ': AccentChar(char='u', accent='ˇ'),
    'ǖ': AccentChar(char='u', accent='¨'),
    'ǘ': AccentChar(char='u', accent='¨'),
    'ǚ': AccentChar(char='u', accent='¨'),
    'ǜ': AccentChar(char='u', accent='¨'),
    'ȕ': AccentChar(char='u', accent='`'),
    'ȗ': AccentChar(char='u', accent='¨'),
    'ū': AccentChar(char='u', accent='-'),
    'ý': AccentChar(char='y', accent='´'),
    'ỳ': AccentChar(char='y', accent='`'),
    'ŷ': AccentChar(char='y', accent='^'),
    'ÿ': AccentChar(char='y', accent='¨'),
    'ȳ': AccentChar(char='y', accent='-'),
    'Á': AccentChar(char='A', accent='´'),
    'À': AccentChar(char='A', accent='`'),
    'Â': AccentChar(char='A', accent='^'),
    'Ã': AccentChar(char='A', accent='~'),
    'Ä': AccentChar(char='A', accent='¨'),
    'Å': AccentChar(char='A', accent='˚'),
    'Å': AccentChar(char='A', accent='˚'),
    'Ȧ': AccentChar(char='A', accent='˙'),
    'Ă': AccentChar(char='A', accent='˘'),
    'Ǎ': AccentChar(char='A', accent='ˇ'),
    'Ǟ': AccentChar(char='A', accent='˝'),
    'Ǻ': AccentChar(char='A', accent='˚'),
    'Ǡ': AccentChar(char='A', accent='-'),
    'Ā': AccentChar(char='A', accent='-'),
    'É': AccentChar(char='E', accent='´'),
    'È': AccentChar(char='E', accent='`'),
    'Ė': AccentChar(char='E', accent='˙'),
    'Ê': AccentChar(char='E', accent='^'),
    'Ë': AccentChar(char='E', accent='¨'),
    'Ě': AccentChar(char='E', accent='ˇ'),
    'Ȅ': AccentChar(char='E', accent='`'),
    'Ȇ': AccentChar(char='E', accent='¨'),
    'Ē': AccentChar(char='E', accent='-'),
    'Í': AccentChar(char='I', accent='´'),
    'Ì': AccentChar(char='I', accent='`'),
    'Î': AccentChar(char='I', accent='^'),
    'Ï': AccentChar(char='I', accent='¨'),
    'Ĭ': AccentChar(char='I', accent='˘'),
    'Ǐ': AccentChar(char='I', accent='ˇ'),
    'Ȉ': AccentChar(char='I', accent='`'),
    'Ȋ': AccentChar(char='I', accent='¨'),
    'Ī': AccentChar(char='I', accent='-'),
    'Ó': AccentChar(char='O', accent='´'),
    'Ò': AccentChar(char='O', accent='`'),
    'Ô': AccentChar(char='O', accent='^'),
    'Õ': AccentChar(char='O', accent='~'),
    'Ö': AccentChar(char='O', accent='¨'),
    'Ő': AccentChar(char='O', accent='˝'),
    'Ǒ': AccentChar(char='O', accent='ˇ'),
    'Ȍ': AccentChar(char='O', accent='`'),
    'Ȏ': AccentChar(char='O', accent='¨'),
    'Ȫ': AccentChar(char='O', accent='˘'),
    'Ȭ': AccentChar(char='O', accent='˝'),
    'Ȯ': AccentChar(char='O', accent='˙'),
    'Ō': AccentChar(char='O', accent='-'),
    'Ú': AccentChar(char='U', accent='´'),
    'Ù': AccentChar(char='U', accent='`'),
    'Û': AccentChar(char='U', accent='^'),
    'Ü': AccentChar(char='U', accent='¨'),
    'Ű': AccentChar(char='U', accent='˝'),
    'Ǔ': AccentChar(char='U', accent='ˇ'),
    'Ǖ': AccentChar(char='U', accent='¨'),
    'Ȕ': AccentChar(char='U', accent='`'),
    'Ȗ': AccentChar(char='U', accent='¨'),
    'Ū': AccentChar(char='U', accent='-'),
    'Ý': AccentChar(char='Y', accent='´'),
    'Ỳ': AccentChar(char='Y', accent='`'),
    'Ŷ': AccentChar(char='Y', accent='^'),
    'Ÿ': AccentChar(char='Y', accent='¨'),
    'Ȳ': AccentChar(char='Y', accent='-'),
    'ñ': AccentChar(char='n', accent='~'),
    'Ñ': AccentChar(char='N', accent='~'),
    'ç': AccentChar(char='c', accent='˙'),
    'Ç': AccentChar(char='C', accent='˙'),
    'ṽ': AccentChar(char='v', accent='~'),
    'Ṽ': AccentChar(char='V', accent='~'),
    'ĵ': AccentChar(char='j', accent='^'),
    'Ĵ': AccentChar(char='J', accent='^'),
    'ź': AccentChar(char='z', accent='´'),
    'Ź': AccentChar(char='Z', accent='´'),
    'Ż': AccentChar(char='Z', accent='^'),
    'ż': AccentChar(char='z', accent='^'),
    'Ž': AccentChar(char='Z', accent='ˇ'),
    'ž': AccentChar(char='z', accent='ˇ'),
    'ẑ': AccentChar(char='z', accent='ˆ'),
}

accent_to_ltx_cmd: Dict[str, str] = {
    '´': 'acute',
    '`': 'grave',
    '^': 'hat',
    '~': 'tilde',
    '¨': 'ddot',
    '˚': 'mathring',
    '˘': 'breve',
    'ˇ': 'check',
    '˝': 'ddot',
    '˙': 'dot',
    '-': 'bar',
    'ˆ': 'hat',
    '˜': 'tilde',
}

special_font_chars: Dict[str, SpecialFontChar] = {
    # mathbf
    '𝐀': SpecialFontChar(letter='A', font_cmd='mathbf'),
    '𝐁': SpecialFontChar(letter='B', font_cmd='mathbf'),
    '𝐂': SpecialFontChar(letter='C', font_cmd='mathbf'),
    '𝐃': SpecialFontChar(letter='D', font_cmd='mathbf'),
    '𝐄': SpecialFontChar(letter='E', font_cmd='mathbf'),
    'Ε': SpecialFontChar(letter='E', font_cmd='mathbf'),
    '𝐅': SpecialFontChar(letter='F', font_cmd='mathbf'),
    '𝐆': SpecialFontChar(letter='G', font_cmd='mathbf'),
    '𝐇': SpecialFontChar(letter='H', font_cmd='mathbf'),
    '𝐈': SpecialFontChar(letter='I', font_cmd='mathbf'),
    '𝐉': SpecialFontChar(letter='J', font_cmd='mathbf'),
    '𝐊': SpecialFontChar(letter='K', font_cmd='mathbf'),
    '𝐋': SpecialFontChar(letter='L', font_cmd='mathbf'),
    '𝐌': SpecialFontChar(letter='M', font_cmd='mathbf'),
    '𝐍': SpecialFontChar(letter='N', font_cmd='mathbf'),
    '𝐎': SpecialFontChar(letter='O', font_cmd='mathbf'),
    '𝐏': SpecialFontChar(letter='P', font_cmd='mathbf'),
    '𝐐': SpecialFontChar(letter='Q', font_cmd='mathbf'),
    '𝐑': SpecialFontChar(letter='R', font_cmd='mathbf'),
    '𝐒': SpecialFontChar(letter='S', font_cmd='mathbf'),
    '𝐓': SpecialFontChar(letter='T', font_cmd='mathbf'),
    '𝐔': SpecialFontChar(letter='U', font_cmd='mathbf'),
    '𝐕': SpecialFontChar(letter='V', font_cmd='mathbf'),
    '𝐖': SpecialFontChar(letter='W', font_cmd='mathbf'),
    '𝐗': SpecialFontChar(letter='X', font_cmd='mathbf'),
    '𝞆': SpecialFontChar(letter='X', font_cmd='mathbf'),
    '𝐘': SpecialFontChar(letter='Y', font_cmd='mathbf'),
    '𝐙': SpecialFontChar(letter='Z', font_cmd='mathbf'),
    '𝟎': SpecialFontChar(letter='0', font_cmd='mathbf'),
    '𝟏': SpecialFontChar(letter='1', font_cmd='mathbf'),
    '𝟐': SpecialFontChar(letter='2', font_cmd='mathbf'),
    '𝟑': SpecialFontChar(letter='3', font_cmd='mathbf'),
    '𝟒': SpecialFontChar(letter='4', font_cmd='mathbf'),
    '𝟓': SpecialFontChar(letter='5', font_cmd='mathbf'),
    '𝟔': SpecialFontChar(letter='6', font_cmd='mathbf'),
    '𝟕': SpecialFontChar(letter='7', font_cmd='mathbf'),
    '𝟖': SpecialFontChar(letter='8', font_cmd='mathbf'),
    '𝟗': SpecialFontChar(letter='9', font_cmd='mathbf'),

    # mathit
    '𝐴': SpecialFontChar(letter='A', font_cmd='mathit'),
    '𝐵': SpecialFontChar(letter='B', font_cmd='mathit'),
    '𝐶': SpecialFontChar(letter='C', font_cmd='mathit'),
    '𝐷': SpecialFontChar(letter='D', font_cmd='mathit'),
    '𝐸': SpecialFontChar(letter='E', font_cmd='mathit'),
    '𝐹': SpecialFontChar(letter='F', font_cmd='mathit'),
    '𝐺': SpecialFontChar(letter='G', font_cmd='mathit'),
    '𝐻': SpecialFontChar(letter='H', font_cmd='mathit'),
    '𝐼': SpecialFontChar(letter='I', font_cmd='mathit'),
    'Ι': SpecialFontChar(letter='I', font_cmd='mathit'),
    '𝐽': SpecialFontChar(letter='J', font_cmd='mathit'),
    '𝐾': SpecialFontChar(letter='K', font_cmd='mathit'),
    '𝐿': SpecialFontChar(letter='L', font_cmd='mathit'),
    '𝑀': SpecialFontChar(letter='M', font_cmd='mathit'),
    '𝑁': SpecialFontChar(letter='N', font_cmd='mathit'),
    '𝑂': SpecialFontChar(letter='O', font_cmd='mathit'),
    '𝑃': SpecialFontChar(letter='P', font_cmd='mathit'),
    '𝑄': SpecialFontChar(letter='Q', font_cmd='mathit'),
    '𝑅': SpecialFontChar(letter='R', font_cmd='mathit'),
    '𝑆': SpecialFontChar(letter='S', font_cmd='mathit'),
    '𝑇': SpecialFontChar(letter='T', font_cmd='mathit'),
    '𝑈': SpecialFontChar(letter='U', font_cmd='mathit'),
    '𝑉': SpecialFontChar(letter='V', font_cmd='mathit'),
    '𝑊': SpecialFontChar(letter='W', font_cmd='mathit'),
    '𝑋': SpecialFontChar(letter='X', font_cmd='mathit'),
    '𝑌': SpecialFontChar(letter='Y', font_cmd='mathit'),
    '𝑍': SpecialFontChar(letter='Z', font_cmd='mathit'),

    # mathbb
    '𝔸': SpecialFontChar(letter='A', font_cmd='mathbb'),
    '𝔹': SpecialFontChar(letter='B', font_cmd='mathbb'),
    'ℂ': SpecialFontChar(letter='C', font_cmd='mathbb'),
    '𝔻': SpecialFontChar(letter='D', font_cmd='mathbb'),
    '𝔼': SpecialFontChar(letter='E', font_cmd='mathbb'),
    '𝔽': SpecialFontChar(letter='F', font_cmd='mathbb'),
    '𝔾': SpecialFontChar(letter='G', font_cmd='mathbb'),
    'ℍ': SpecialFontChar(letter='H', font_cmd='mathbb'),
    '𝕀': SpecialFontChar(letter='I', font_cmd='mathbb'),
    '𝕁': SpecialFontChar(letter='J', font_cmd='mathbb'),
    '𝕂': SpecialFontChar(letter='K', font_cmd='mathbb'),
    '𝕃': SpecialFontChar(letter='L', font_cmd='mathbb'),
    '𝕄': SpecialFontChar(letter='M', font_cmd='mathbb'),
    'ℕ': SpecialFontChar(letter='N', font_cmd='mathbb'),
    '𝕆': SpecialFontChar(letter='O', font_cmd='mathbb'),
    'ℙ': SpecialFontChar(letter='P', font_cmd='mathbb'),
    'ℚ': SpecialFontChar(letter='Q', font_cmd='mathbb'),
    'ℝ': SpecialFontChar(letter='R', font_cmd='mathbb'),
    '𝕊': SpecialFontChar(letter='S', font_cmd='mathbb'),
    '𝕋': SpecialFontChar(letter='T', font_cmd='mathbb'),
    '𝕌': SpecialFontChar(letter='U', font_cmd='mathbb'),
    '𝕍': SpecialFontChar(letter='V', font_cmd='mathbb'),
    '𝕎': SpecialFontChar(letter='W', font_cmd='mathbb'),
    '𝕏': SpecialFontChar(letter='X', font_cmd='mathbb'),
    '𝕐': SpecialFontChar(letter='Y', font_cmd='mathbb'),
    'ℤ': SpecialFontChar(letter='Z', font_cmd='mathbb'),
    '𝟘': SpecialFontChar(letter='0', font_cmd='mathbb'),
    '𝟙': SpecialFontChar(letter='1', font_cmd='mathbb'),
    '𝟚': SpecialFontChar(letter='2', font_cmd='mathbb'),
    '𝟛': SpecialFontChar(letter='3', font_cmd='mathbb'),
    '𝟜': SpecialFontChar(letter='4', font_cmd='mathbb'),
    '𝟝': SpecialFontChar(letter='5', font_cmd='mathbb'),
    '𝟞': SpecialFontChar(letter='6', font_cmd='mathbb'),
    '𝟟': SpecialFontChar(letter='7', font_cmd='mathbb'),
    '𝟠': SpecialFontChar(letter='8', font_cmd='mathbb'),
    '𝟡': SpecialFontChar(letter='9', font_cmd='mathbb'),

    # mathcal
    '𝒜': SpecialFontChar(letter='A', font_cmd='mathcal'),
    '𝓐': SpecialFontChar(letter='A', font_cmd='mathcal'),
    'ℬ': SpecialFontChar(letter='B', font_cmd='mathcal'),
    '𝒞': SpecialFontChar(letter='C', font_cmd='mathcal'),
    '𝒟': SpecialFontChar(letter='D', font_cmd='mathcal'),
    '𝓓': SpecialFontChar(letter='D', font_cmd='mathcal'),
    'ℰ': SpecialFontChar(letter='E', font_cmd='mathcal'),
    'ℱ': SpecialFontChar(letter='F', font_cmd='mathcal'),
    '𝓕': SpecialFontChar(letter='F', font_cmd='mathcal'),
    '𝒢': SpecialFontChar(letter='G', font_cmd='mathcal'),
    'ℋ': SpecialFontChar(letter='H', font_cmd='mathcal'),
    'ℐ': SpecialFontChar(letter='I', font_cmd='mathcal'),
    '𝒥': SpecialFontChar(letter='J', font_cmd='mathcal'),
    '𝒦': SpecialFontChar(letter='K', font_cmd='mathcal'),
    'ℒ': SpecialFontChar(letter='L', font_cmd='mathcal'),
    '𝓛': SpecialFontChar(letter='L', font_cmd='mathcal'),
    'ℳ': SpecialFontChar(letter='M', font_cmd='mathcal'),
    '𝒩': SpecialFontChar(letter='N', font_cmd='mathcal'),
    '𝒪': SpecialFontChar(letter='O', font_cmd='mathcal'),
    '𝓞': SpecialFontChar(letter='O', font_cmd='mathcal'),
    '𝒫': SpecialFontChar(letter='P', font_cmd='mathcal'),
    '𝒬': SpecialFontChar(letter='Q', font_cmd='mathcal'),
    'ℛ': SpecialFontChar(letter='R', font_cmd='mathcal'),
    '𝕽': SpecialFontChar(letter='R', font_cmd='mathcal'),
    '℟': SpecialFontChar(letter='R', font_cmd='mathcal'),
    '𝒮': SpecialFontChar(letter='S', font_cmd='mathcal'),
    '𝒯': SpecialFontChar(letter='T', font_cmd='mathcal'),
    '𝒰': SpecialFontChar(letter='U', font_cmd='mathcal'),
    '𝒱': SpecialFontChar(letter='V', font_cmd='mathcal'),
    '𝒲': SpecialFontChar(letter='W', font_cmd='mathcal'),
    '𝒳': SpecialFontChar(letter='X', font_cmd='mathcal'),
    '𝒴': SpecialFontChar(letter='Y', font_cmd='mathcal'),
    '𝒵': SpecialFontChar(letter='Z', font_cmd='mathcal'),

    # mathfrak
    '𝔄': SpecialFontChar(letter='A', font_cmd='mathfrak'),
    '𝔅': SpecialFontChar(letter='B', font_cmd='mathfrak'),
    'ℭ': SpecialFontChar(letter='C', font_cmd='mathfrak'),
    '𝔇': SpecialFontChar(letter='D', font_cmd='mathfrak'),
    '𝔈': SpecialFontChar(letter='E', font_cmd='mathfrak'),
    '𝔉': SpecialFontChar(letter='F', font_cmd='mathfrak'),
    '𝔊': SpecialFontChar(letter='G', font_cmd='mathfrak'),
    'ℌ': SpecialFontChar(letter='H', font_cmd='mathfrak'),
    'ℑ': SpecialFontChar(letter='I', font_cmd='mathfrak'),
    '𝔍': SpecialFontChar(letter='J', font_cmd='mathfrak'),
    '𝔎': SpecialFontChar(letter='K', font_cmd='mathfrak'),
    '𝔏': SpecialFontChar(letter='L', font_cmd='mathfrak'),
    '𝔐': SpecialFontChar(letter='M', font_cmd='mathfrak'),
    '𝔑': SpecialFontChar(letter='N', font_cmd='mathfrak'),
    '𝔒': SpecialFontChar(letter='O', font_cmd='mathfrak'),
    '𝔓': SpecialFontChar(letter='P', font_cmd='mathfrak'),
    '𝔔': SpecialFontChar(letter='Q', font_cmd='mathfrak'),
    'ℜ': SpecialFontChar(letter='R', font_cmd='mathfrak'),
    '𝔖': SpecialFontChar(letter='S', font_cmd='mathfrak'),
    '𝔗': SpecialFontChar(letter='T', font_cmd='mathfrak'),
    '𝔘': SpecialFontChar(letter='U', font_cmd='mathfrak'),
    '𝔙': SpecialFontChar(letter='V', font_cmd='mathfrak'),
    '𝔚': SpecialFontChar(letter='W', font_cmd='mathfrak'),
    '𝔛': SpecialFontChar(letter='X', font_cmd='mathfrak'),
    '𝔜': SpecialFontChar(letter='Y', font_cmd='mathfrak'),
    'ℨ': SpecialFontChar(letter='Z', font_cmd='mathfrak'),

    # mathsf
    '𝖠': SpecialFontChar(letter='A', font_cmd='mathsf'),
    'Α': SpecialFontChar(letter='A', font_cmd='mathsf'),
    '𝖡': SpecialFontChar(letter='B', font_cmd='mathsf'),
    'Β': SpecialFontChar(letter='B', font_cmd='mathsf'),
    '𝖢': SpecialFontChar(letter='C', font_cmd='mathsf'),
    '𝖣': SpecialFontChar(letter='D', font_cmd='mathsf'),
    '𝖤': SpecialFontChar(letter='E', font_cmd='mathsf'),
    '𝖥': SpecialFontChar(letter='F', font_cmd='mathsf'),
    '𝖦': SpecialFontChar(letter='G', font_cmd='mathsf'),
    '𝖧': SpecialFontChar(letter='H', font_cmd='mathsf'),
    '𝖨': SpecialFontChar(letter='I', font_cmd='mathsf'),
    '𝖩': SpecialFontChar(letter='J', font_cmd='mathsf'),
    'ȷ': SpecialFontChar(letter='J', font_cmd='mathsf'),
    '𝖪': SpecialFontChar(letter='K', font_cmd='mathsf'),
    'Κ': SpecialFontChar(letter='K', font_cmd='mathsf'),
    '𝖫': SpecialFontChar(letter='L', font_cmd='mathsf'),
    '𝖬': SpecialFontChar(letter='M', font_cmd='mathsf'),
    '𝖭': SpecialFontChar(letter='N', font_cmd='mathsf'),
    '𝖮': SpecialFontChar(letter='O', font_cmd='mathsf'),
    '𝖯': SpecialFontChar(letter='P', font_cmd='mathsf'),
    '𝖰': SpecialFontChar(letter='Q', font_cmd='mathsf'),
    '𝖱': SpecialFontChar(letter='R', font_cmd='mathsf'),
    '𝖲': SpecialFontChar(letter='S', font_cmd='mathsf'),
    '𝖳': SpecialFontChar(letter='T', font_cmd='mathsf'),
    '𝖴': SpecialFontChar(letter='U', font_cmd='mathsf'),
    '𝖵': SpecialFontChar(letter='V', font_cmd='mathsf'),
    '𝖶': SpecialFontChar(letter='W', font_cmd='mathsf'),
    '𝖷': SpecialFontChar(letter='X', font_cmd='mathsf'),
    'Χ': SpecialFontChar(letter='X', font_cmd='mathsf'),
    '𝖸': SpecialFontChar(letter='Y', font_cmd='mathsf'),
    '𝖹': SpecialFontChar(letter='Z', font_cmd='mathsf'),

    # mathtt
    '𝚨': SpecialFontChar(letter='A', font_cmd='mathtt'),
    '𝚩': SpecialFontChar(letter='B', font_cmd='mathtt'),
    '𝚪': SpecialFontChar(letter='\\Gamma', font_cmd='mathtt'),
    '𝚫': SpecialFontChar(letter='\\Delta', font_cmd='mathtt'),
    '𝚬': SpecialFontChar(letter='E', font_cmd='mathtt'),
    '𝚭': SpecialFontChar(letter='F', font_cmd='mathtt'),
    '𝚮': SpecialFontChar(letter='G', font_cmd='mathtt'),
    '𝚯': SpecialFontChar(letter='\\Theta', font_cmd='mathtt'),
    '𝚰': SpecialFontChar(letter='I', font_cmd='mathtt'),
    '𝚱': SpecialFontChar(letter='J', font_cmd='mathtt'),
    '𝚲': SpecialFontChar(letter='\\Lambda', font_cmd='mathtt'),
    '𝚳': SpecialFontChar(letter='L', font_cmd='mathtt'),
    '𝚴': SpecialFontChar(letter='M', font_cmd='mathtt'),
    '𝚵': SpecialFontChar(letter='\\Pi', font_cmd='mathtt'),
    '𝚶': SpecialFontChar(letter='O', font_cmd='mathtt'),
    '𝚷': SpecialFontChar(letter='\\Pi', font_cmd='mathtt'),
    '𝚸': SpecialFontChar(letter='Q', font_cmd='mathtt'),
    '𝚹': SpecialFontChar(letter='R', font_cmd='mathtt'),
    '𝚺': SpecialFontChar(letter='S', font_cmd='mathtt'),
    '𝚻': SpecialFontChar(letter='T', font_cmd='mathtt'),
    '𝚼': SpecialFontChar(letter='U', font_cmd='mathtt'),
    '𝚽': SpecialFontChar(letter='\\Phi', font_cmd='mathtt'),
    '𝚾': SpecialFontChar(letter='W', font_cmd='mathtt'),
    '𝚿': SpecialFontChar(letter='\\Psi', font_cmd='mathtt'),
    '𝛀': SpecialFontChar(letter='\\Omega', font_cmd='mathtt'),
}

all_math_symbols_by_char: Dict[str, str] = {
    '&#xA0;': '\\textrm{ }',
    '&#x2203;': '\\exists',
    '&#x2200;': '\\forall',
    '&#x21D4;': '\\iff',
    '&#x21D2;': '=>',
    '&#xAC;': '\\neg',
    '&#x2124;': '\\mathbb{Z}',
    '&#x211D;': '\\mathbb{R}',
    '&#x211A;': '\\mathbb{Q}',
    '&#x2115;': '\\mathbb{N}',
    '&#x2102;': 'CC',
    '&#x25A1;': '\\square',
    '&#x22C4;': '\\diamond',
    '&#x25B3;': '\\triangle',
    '&#x2322;': '\\frown',
    '&#x2220;': '\\angle',
    '&#x22F1;': '\\ddots',
    '&#x22EE;': '\\vdots',
    '&#x2235;': '\\because',
    '&#x2234;': '\\therefore',
    '&#x2135;': '\\aleph',
    '&#x2205;': '\\oslash',
    '&#xB1;': '\\pm',
    '&#x2207;': '\\nabla',
    '&#x2202;': '\\partial',
    '&#x222E;': '\\oint',
    '&#x222B;': '\\int',
    '&#x22C3;': '\\cup',
    '&#x222A;': '\\cup',
    '&#x22C2;': '\\cap',
    '&#x2229;': '\\cap',
    '&#x22C1;': '\\vee',
    '&#x2228;': '\\vee',
    '&#x22C0;': '\\wedge',
    '&#x2227;': '\\wedge',
    '&#x220F;': '\\prod',
    '&#x2211;': '\\sum',
    '&#x2299;': '\\bigodot',
    '&#x2297;': '\\bigoplus',
    '&#x2295;': 'o+',
    '&#x2218;': '@',
    '&#x22C8;': '\\bowtie',
    '&#x22CA;': '\\rtimes',
    '&#x22C9;': '\\ltimes',
    '&#xF7;': '\\div',
    '&#xD7;': '\\times',
    '\\': '\\backslash',
    '&#x22C6;': '\\star',
    '&#x2217;': '\\star',
    '&#x22C5;': '\\cdot',
    '&#x3A9;': '\\Omega',
    '&#x3C9;': '\\omega',
    '&#x3A8;': '\\Psi',
    '&#x3C8;': '\\psi',
    '&#x3C7;': '\\chi',
    '&#x3C6;': '\\varphi',
    '&#x3A6;': '\\Phi',
    '&#x3D5;': '\\phi',
    '&#x3C5;': '\\upsilon',
    '&#x3C4;': '\\tau',
    '&#x3A3;': '\\Sigma',
    '&#x3C3;': '\\sigma',
    '&#x3C1;': '\\rho',
    '&#x3A0;': '\\Pi',
    '&#x3C0;': '\\pi',
    '&#x39E;': '\\Xi',
    '&#x3BE;': '\\xi',
    '&#x3BD;': '\\nu',
    '&#x3BC;': '\\mu',
    '&#x39B;': '\\Lambda',
    '&#x3BB;': '\\lambda',
    '&#x3BA;': '\\kappa',
    '&#x3B9;': '\\iota',
    '&#x3D1;': '\\vartheta',
    '&#x398;': '\\Theta',
    '&#x3B8;': '\\theta',
    '&#x3B7;': '\\eta',
    '&#x3B6;': '\\zeta',
    '&#x25B;': '\\varepsilon',
    '&#x3B5;': '\\epsilon',
    '&#x394;': '\\Delta',
    '&#x3B4;': '\\delta',
    '&#x393;': '\\Gamma',
    '&#x3B3;': '\\gamma',
    '&#x3B2;': '\\beta',
    '&#x3B1;': '\\alpha',
    '&#x221E;': '\\infty',
    '\u202c': '\\text{\\textdir TRT}',
    '\u200e': '\\text{\\textdir LTR}',
}

all_math_symbols_by_glyph: Dict[str, str] = {
    ' ': r'\textrm{ }',
    '∃': r'\exists',
    '∀': r'\forall',
    '⇔': r'\iff',
    '⇒': r'\Rightarrow',
    '¬': r'\neg',
    '□': r'\square',
    '⋄': r'\diamond',
    '△': r'\triangle',
    '⌢': r'\frown',
    '∠': r'\angle',
    '⋱': r'\ddots',
    '⋮': r'\vdots',
    '∵': r'\because',
    '∴': r'\therefore',
    'ℵ': r'\aleph',
    '∅': r'\emptyset',
    '±': r'\pm',
    '∇': r'\nabla',
    '∂': r'\partial',
    '∮': r'\oint',
    '∫': r'\int',
    '⋃': r'\cup',
    '∪': r'\cup',
    '⋂': r'\cap',
    '∩': r'\cap',
    '⋁': r'\vee',
    '∨': r'\vee',
    '⋀': r'\wedge',
    '∧': r'\wedge',
    '∏': r'\prod',
    '∑': r'\sum',
    '⊙': r'\bigodot',
    '⊗': r'\bigoplus',
    '⊕': 'o+',
    '∘': '@',
    '⋈': r'\bowtie',
    '⋊': r'\rtimes',
    '⋉': r'\ltimes',
    '÷': r'\div',
    '×': r'\times',
    '\\': r'\backslash',
    '⋆': r'\star',
    '∗': r'\star',
    '⋅': r'\cdot',
    'Ω': r'\Omega',
    'ω': r'\omega',
    'Ψ': r'\Psi',
    'ψ': r'\psi',
    'χ': r'\chi',
    'φ': r'\varphi',
    'Φ': r'\Phi',
    'ϕ': r'\phi',
    'υ': r'\upsilon',
    'τ': r'\tau',
    'Σ': r'\Sigma',
    'σ': r'\sigma',
    'ρ': r'\rho',
    'Π': r'\Pi',
    'π': r'\pi',
    'Ξ': r'\Xi',
    'ξ': r'\xi',
    'ν': r'\nu',
    'μ': r'\mu',
    'Λ': r'\Lambda',
    'λ': r'\lambda',
    'κ': r'\kappa',
    'ι': r'\iota',
    'ϑ': r'\vartheta',
    'Θ': r'\Theta',
    'θ': r'\theta',
    'η': r'\eta',
    'ζ': r'\zeta',
    'ɛ': r'\varepsilon',
    'ε': r'\epsilon',
    'Δ': r'\Delta',
    'δ': r'\delta',
    'Γ': r'\Gamma',
    'γ': r'\gamma',
    'β': r'\beta',
    'α': r'\alpha',
    '∞': r'\infty',
    'ϵ': r'\epsilon',
    'µ': r'\mu',
    '²': r'^{2}',
    'ı': r'\imath',
    '∎': r'\blacksquare',
    'ม': r'\mathbf{m}',
    'Ω': r'\Omega',
    '⟲': r'\circlearrowleft',
    '⟳': r'\circlearrowright',
    'त': ' ',
    '¥': r'\yen',
    '⁽': r'^{(}',
    '⁾': r'^{)}',
    'ß': r'\ss',
    'Ћ': r'\hbar',
    '⦵': r'\ominus',
    '⊿': r'\bigtriangleup',
    "↛'": r'\nrightarrow',
    '†': r'\dagger',
    'เ': r'\prime',
    '白': ' ',
    '⿱': ' ',
    'ℸ': r'\wp',
    '픀': ' ',
    'ⁿ': r'^{n}',
    '✔': r'\checkmark',
    '✗': r'\times',
    '½': r'\dfrac{1}{2}',
    'Ө': r'\theta',
    '✓': r'\checkmark',
    '⟩': r'\rangle',
    '⟨': r'\langle',
    '〈': r'\langle',
    '¼': r'\dfrac{1}{4}',
    '…': r'\ldots',
    'ℏ': r'\hbar',
    'ℜ': r'\mathfrak{R}',
    'Ѳ': r'\theta',
    'Ø': r'\emptyset',
    'ϱ': r'\varrho',
    'ф': r'\phi',
    'T': 'T',
    '∙': r'\cdot',
    'Ρ': 'P',
    'ᐁ': r'\nabla',
    'ƞ': r'\eta',
    'ɣ': r'\gamma',
    'ћ': r'\hbar',
    'Ɛ': r'\varepsilon',
    'ⅅ': r'\_{D}',
    '𝜆': r'\lambda',
    '〗': r'\rangle',
    '〖': r'\langle',
    ';': ';',
    '𝑥': 'x',
    '𝑦': 'y',
    '𝑧': 'z',
    '𝑖': 'i',
    '𝑗': 'j',
    '𝑘': 'k',
    '𝑚': 'm',
    '𝑒': 'e',
    '𝑟': 'r',
    'ɳ': r'\eta',
    '𝛽': r'\beta',
    '⍵': r'\omega',
    '℘': r'\wp',
    '𝜋': r'\pi',
    'Є': r'\epsilon',
    'є': r'\epsilon',
    '𝜀': r'\epsilon',
    'п': r'\pi',
    'Ν': r'\nu',
    'ɵ': r'\theta',
    '𝜓': r'\psi',
    'ϴ': r'\theta',
    'ɸ': r'\phi',
    'Ӷ': r'\Gamma',
    'ɭ': r'\ell',
    'ʋ': r'\upsilon',
    '𝛟': r'\varphi',
    '⍬': r'\theta',
    'Ф': r'\Phi',
    '𝜑': r'\varphi',
    'ⅈ': 'i',
    'ο': 'o',
    'ơ': 'o',
    'ƒ': 'f',
    '⍴': r'\rho',
    '🇽': 'x',
    '𝑝': 'p',
    '𝑞': 'q',
    '𝑠': 's',
    '𝑡': 't',
    '𝑢': 'u',
    '𝑣': 'v',
    '𝑤': 'w',
    '𝑎': 'a',
    '𝑏': 'b',
    '𝑐': 'c',
    '𝑑': 'd',
    '𝑓': 'f',
    '𝑔': 'g',
    '𝑙': 'l',
    '𝑛': 'n',
    '𝑜': 'o',
    '𝔀': 'w',
    '𝚟': 'v',
    'ṁ': 'm',
    '൦': r'\circ',
    '┴': r'\perp',
    '✕': r'\times',
    '∣': r'\mid',
    'Փ': r'\Phi',
    '⎜': r'\mid',
    'ħ': r'\hbar',
    'ፈ': ' ',
    '⦨': r'\llbracket',
    'ế': r'\hat{e}',
    '¢': r'\cent',
    '⤹': r'\downarrow',
    '⤸': r'\downarrow',
    '⤷': r'\Rsh',
    '⤶': r'\Lsh',
    '⤵': r'\downarrow',
    '⤴': r'\uparrow',
    '⤳': r'\rightarrow',
    '|': r'\mid',
    '⎥': r'\mid',
    '♥': r'\heartsuit',
    'О': '0',
    'Υ': 'Y',
    'х': 'x',
    '𝓏': 'z',
    '𝓎': 'y',
    '𝓍': 'x',
    'р': 'p',
    'а': 'a',
    '£': r'\pounds',
    'm': 'm',
    '𝚵': r'\Xi',
    '⓪': r'\textcircled{0}',
    '①': r'\textcircled{1}',
    '②': r'\textcircled{2}',
    '③': r'\textcircled{3}',
    '④': r'\textcircled{4}',
    '⑤': r'\textcircled{5}',
    '⑥': r'\textcircled{6}',
    '⑦': r'\textcircled{7}',
    '⑧': r'\textcircled{8}',
    '⑨': r'\textcircled{9}',
    '⑩': r'\textcircled{10}',
    '⑪': r'\textcircled{11}',
    '⑫': r'\textcircled{12}',
    '⑬': r'\textcircled{13}',
    '⑭': r'\textcircled{14}',
    '⑮': r'\textcircled{15}',
    '⑯': r'\textcircled{16}',
    '⑰': r'\textcircled{17}',
    '⑱': r'\textcircled{18}',
    '⑲': r'\textcircled{19}',
    '⑳': r'\textcircled{20}',
    '㉑': r'\textcircled{21}',
    '㉒': r'\textcircled{22}',
    '㉓': r'\textcircled{23}',
    '㉔': r'\textcircled{24}',
    '㉕': r'\textcircled{25}',
    '㉖': r'\textcircled{26}',
    '㉗': r'\textcircled{27}',
    '㉘': r'\textcircled{28}',
    '㉙': r'\textcircled{29}',
    '㉚': r'\textcircled{30}',
    '㉛': r'\textcircled{31}',
    '㉜': r'\textcircled{32}',
    '㉝': r'\textcircled{33}',
    '㉞': r'\textcircled{34}',
    '㉟': r'\textcircled{35}',
    '㊱': r'\textcircled{36}',
    '㊲': r'\textcircled{37}',
    '㊳': r'\textcircled{38}',
    '㊴': r'\textcircled{39}',
    '㊵': r'\textcircled{40}',
    '㊶': r'\textcircled{41}',
    '㊷': r'\textcircled{42}',
    '㊸': r'\textcircled{43}',
    '㊹': r'\textcircled{44}',
    '㊺': r'\textcircled{45}',
    '㊻': r'\textcircled{46}',
    '㊼': r'\textcircled{47}',
    '㊽': r'\textcircled{48}',
    '㊾': r'\textcircled{49}',
    '㊿': r'\textcircled{50}',
    '&': r'\&',
    '‖': r'\parallel',
    '%': r'\%',
    '“': r'\text{``}',
    '$': r'\$',
    '#': r'\#',
    '℃': r'\text{\textdegree C}',
    '℉': r'\text{\textdegree F}',
    '█': r'\blacksquare',
    '℧': r'\mho',
    '⌋': r'\rfloor',
    '⌊': r'\lfloor',
    '⌉': r'\rceil',
    '⌈': r'\lceil',
    'ℇ': r'\varepsilon',
    'ⅇ': r'\text{e}',
    'ɼ': 'r',
    '↛': r'\nrightarrow',
    'ˆ': r'\hat{}',
    '‾': r'\overline',
    '→': r'\rightarrow',
    '‡': r'\ddagger',
    '・': r'\cdot',
    '▱': r'\square',
    '∆': r'\Delta',
    'ἱ': 'i',
    '∡': r'\angle',
    'ϒ': r'\Upsilon',
    '↓': r'\downarrow',
    '↑': r'\uparrow',
    '»': r'\gg',
    '⊤': r'\top',
    '⧸': '/',
    '𝛿': r'\delta',
    '˳': r'\cdot',
    '։': ':',
    '⦪': r'\measuredangle',
    '⦩': r'\measuredangle',
    '⦫': r'\measuredangle',
    '⦁': r'\cdot',
    'ѳ': r'\theta',
    '⦢': r'\measuredangle',
    '¸': ',',
    '⎻': r'\overline',
    '⟦': r'\llbracket',
    '𝜙': r'\phi',
    'П': r'\prod',
    'о': 'o',
    '≈': r'\approx',
    '≤': r'\leq',
    'ђ': r'\hbar',
    'Ʌ': r'\Lambda',
    '土': r'\pm',
    '⎼': '-',
    '十': '+',
    '≠': r'\neq',
    '←': r'\leftarrow',
    '।': r'\mid',
    '€': r'\euro',
    '˘': ' ',
    'ῡ': r'\bar{u}',
    '∥': r'\parallel',
    '↔': r'\leftrightarrow',
    '√': r'\sqrt{}',
    'ȼ': 'c',
    '𝞮': r'\epsilon',
    '·': r'\cdot',
    '⦬': r'\measuredangle',
    '⦮': r'\measuredangle',
    '⦭': r'\measuredangle',
    '«': r'\ll',
    'Χ': r'\mathsf{X}',
    '│': r'\mid',
    '〉': r'\rangle',
    'ₙ': r'_{n}',
    '▫': r'\square',
    '●': r'\circle',
    '”': r'\\"',
}

math_number_by_glyph: Dict[str, str] = {
    '₀': '_{0}',
    '₁': '_{1}',
    '₂': '_{2}',
    '₃': '_{3}',
    '₄': '_{4}',
    '₅': '_{5}',
    '₆': '_{6}',
    '₇': '_{7}',
    '₈': '_{8}',
    '₉': '_{9}',
    '⁰': '^{0}',
    '¹': '^{1}',
    '²': '^{2}',
    '³': '^{3}',
    '⁴': '^{4}',
    '⁵': '^{5}',
    '⁶': '^{6}',
    '⁷': '^{7}',
    '⁸': '^{8}',
    '⁹': '^{9}',
    'ⁿ': '^{n}',
    'ₙ': '_{n}',
    '⓪': r'\textcircled{0}',
    '①': r'\textcircled{1}',
    '②': r'\textcircled{2}',
    '③': r'\textcircled{3}',
    '④': r'\textcircled{4}',
    '⑤': r'\textcircled{5}',
    '⑥': r'\textcircled{6}',
    '⑦': r'\textcircled{7}',
    '⑧': r'\textcircled{8}',
    '⑨': r'\textcircled{9}',
    '⑩': r'\textcircled{10}',
    '⑪': r'\textcircled{11}',
    '⑫': r'\textcircled{12}',
    '⑬': r'\textcircled{13}',
    '⑭': r'\textcircled{14}',
    '⑮': r'\textcircled{15}',
    '⑯': r'\textcircled{16}',
    '⑰': r'\textcircled{17}',
    '⑱': r'\textcircled{18}',
    '⑲': r'\textcircled{19}',
    '⑳': r'\textcircled{20}',
    '㉑': r'\textcircled{21}',
    '㉒': r'\textcircled{22}',
    '㉓': r'\textcircled{23}',
    '㉔': r'\textcircled{24}',
    '㉕': r'\textcircled{25}',
    '㉖': r'\textcircled{26}',
    '㉗': r'\textcircled{27}',
    '㉘': r'\textcircled{28}',
    '㉙': r'\textcircled{29}',
    '㉚': r'\textcircled{30}',
    '㉛': r'\textcircled{31}',
    '㉜': r'\textcircled{32}',
    '㉝': r'\textcircled{33}',
    '㉞': r'\textcircled{34}',
    '㉟': r'\textcircled{35}',
    '㊱': r'\textcircled{36}',
    '㊲': r'\textcircled{37}',
    '㊳': r'\textcircled{38}',
    '㊴': r'\textcircled{39}',
    '㊵': r'\textcircled{40}',
    '㊶': r'\textcircled{41}',
    '㊷': r'\textcircled{42}',
    '㊸': r'\textcircled{43}',
    '㊹': r'\textcircled{44}',
    '㊺': r'\textcircled{45}',
    '㊻': r'\textcircled{46}',
    '㊼': r'\textcircled{47}',
    '㊽': r'\textcircled{48}',
    '㊾': r'\textcircled{49}',
    '㊿': r'\textcircled{50}',
    '½': r'\dfrac{1}{2}',
    '⅓': r'\dfrac{1}{3}',
    '⅔': r'\dfrac{2}{3}',
    '¼': r'\dfrac{1}{4}',
    '¾': r'\dfrac{3}{4}',
    '⅕': r'\dfrac{1}{5}',
    '⅖': r'\dfrac{2}{5}',
    '⅗': r'\dfrac{3}{5}',
    '⅘': r'\dfrac{4}{5}',
    '⅙': r'\dfrac{1}{6}',
    '⅚': r'\dfrac{5}{6}',
    '⅐': r'\dfrac{1}{7}',
    '⅛': r'\dfrac{1}{8}',
    '⅜': r'\dfrac{3}{8}',
    '⅝': r'\dfrac{5}{8}',
    '⅞': r'\dfrac{7}{8}',
    '⅑': r'\dfrac{1}{9}',
    '⅒': r'\dfrac{1}{10}',
}

all_math_operators_by_char: Dict[str, str] = {
    '_': '\\underline',
    '&#x23E1;': '\\underbrace',
    '&#x23E0;': '\\overbrace',
    '&#x23DF;': '\\underbrace',
    '&#x23DE;': '\\overbrace',
    '&#x23DD;': '\\underbrace',
    '&#x23DC;': '\\overbrace',
    '&#x23B5;': '\\underbrace',
    '&#x23B4;': '\\overbrace',
    '&#x20DC;': '\\square',
    '&#x20DB;': '\\square',
    '&#x2064;': '',
    '&#x2057;': "''''",
    '&#x203E;': '\\bar',
    '&#x2037;': '```',
    '&#x2036;': '``',
    '&#x2035;': '`',
    '&#x2034;': "'''",
    '&#x2033;': "''",
    '&#x201F;': '``',
    '&#x201E;': ',,',
    '&#x201B;': '`',
    '&#x201A;': ',',
    '&#x302;': '\\hat',
    '&#x2F7;': '\\sim',
    '&#x2DD;': '\\sim',
    '&#x2DC;': '\\sim',
    '&#x2DA;': '\\circ',
    '&#x2D9;': '\\cdot',
    '&#x2D8;': '',
    '&#x2CD;': '\\_',
    '&#x2CB;': 'ˋ',
    '&#x2CA;': 'ˊ',
    '&#x2C9;': 'ˉ',
    '&#x2C7;': '',
    '&#x2C6;': '\\hat',
    '&#xBA;': 'o',
    '&#xB9;': '1',
    '&#xB8;': '¸',
    '&#xB4;': '´',
    '&#xB3;': '3',
    '&#xB2;': '2',
    '&#xB0;': '\\circ',
    '&#xAF;': '\\bar',
    '&#xAA;': 'a',
    '&#xA8;': '\\cdot\\cdot',
    '~': '\\sim',
    '`': '`',
    '^': '\\hat',
    '--': '--',
    '++': '++',
    '&amp;': '\\&',
    '&#x2061;': '',
    '&#x221C;': '\\sqrt[4]{}',
    '&#x221B;': '\\sqrt[3]{}',
    '&#x221A;': '\\sqrt{}',
    '&#x2146;': 'd',
    '&#x2145;': '\\mathbb{D}',
    '?': '?',
    '@': '@',
    '//': '//',
    '!!': '!!',
    '!': '!',
    '&#x266F;': '\\#',
    '&#x266E;': '',
    '&#x266D;': '',
    '&#x2032;': "'",
    '&lt;>': '<>',
    '**': '\\star\\star',
    '&#x2207;': '\\nabla',
    '&#x2202;': '\\partial',
    '&#x2299;': '\\bigodot',
    '&#xAC;': '\\neg',
    '&#x2222;': '\\measuredangle',
    '&#x2221;': '\\measuredangle',
    '&#x2220;': '\\angle',
    '&#xF7;': '\\div',
    '/': '/',
    '&#x2216;': '\\backslash',
    '\\': '\\backslash',
    '%': '\\%',
    '&#x2297;': '\\bigotimes',
    '&#xB7;': '\\cdot',
    '&#x2A3F;': '\\coprod',
    '&#x2A2F;': '\\times',
    '&#x22C5;': '\\cdot',
    '&#x22A1;': '\\boxdot',
    '&#x22A0;': '\\boxtimes',
    '&#x2062;': '',
    '&#x2043;': '-',
    '&#x2022;': '\\cdot',
    '&#xD7;': '\\times',
    '.': '.',
    '*': '\\star',
    '&#x222A;': '\\cup',
    '&#x2229;': '\\cap',
    '&#x2210;': '\\coprod',
    '&#x220F;': '\\prod',
    '&#x2240;': '',
    '&#x2AFF;': '',
    '&#x2AFC;': '\\mid\\mid\\mid',
    '&#x2A09;': '\\times',
    '&#x2A08;': '',
    '&#x2A07;': '',
    '&#x2A06;': '\\sqcup',
    '&#x2A05;': '\\sqcap',
    '&#x2A02;': '\\otimes',
    '&#x2A00;': '\\odot',
    '&#x22C2;': '\\cap',
    '&#x22C1;': '\\vee',
    '&#x22C0;': '\\wedge',
    '&#x2A04;': '\\uplus',
    '&#x2A03;': '\\cup',
    '&#x22C3;': '\\cup',
    '&#x2A1C;': '\\underline{\\int}',
    '&#x2A1B;': '\\overline{\\int}',
    '&#x2A1A;': '\\int',
    '&#x2A19;': '\\int',
    '&#x2A18;': '\\int',
    '&#x2A17;': '\\int',
    '&#x2A16;': '\\oint',
    '&#x2A15;': '\\oint',
    '&#x2A14;': '\\int',
    '&#x2A13;': '\\int',
    '&#x2A12;': '\\int',
    '&#x2A11;': '\\int',
    '&#x2A10;': '\\int',
    '&#x2A0F;': '\\bcancel{\\int}',
    '&#x2A0E;': '',
    '&#x2A0D;': '\\hcancel{\\int}',
    '&#x2A0C;': '\\iiiint',
    '&#x2233;': '\\oint',
    '&#x2232;': '\\oint',
    '&#x2231;': '\\int',
    '&#x2230;': '\\oiint',
    '&#x222F;': '\\oiint',
    '&#x222E;': '\\oint',
    '&#x222B;': '\\int',
    '&#x2A01;': '\\oplus',
    '&#x2298;': '\\oslash',
    '&#x2296;': '\\ominus',
    '&#x2295;': '\\oplus',
    '&#x222D;': '\\iiint',
    '&#x222C;': '\\iint',
    '&#x2A0B;': '',
    '&#x2A0A;': '',
    '&#x2211;': '\\sum',
    '&#x229F;': '\\boxminus',
    '&#x229E;': '\\boxplus',
    '&#x2214;': '\\dot{+}',
    '&#x2213;': '+-',
    '&#x2212;': '-',
    '&#xB1;': '\\pm',
    '-': '-',
    '+': '+',
    '&#x2B46;': '\\Rrightarrow',
    '&#x2B45;': '\\Lleftarrow',
    '&#x29F4;': ':\\rightarrow',
    '&#x29EF;': '',
    '&#x29DF;': '\\bullet-\\bullet',
    '&#x299F;': '\\angle',
    '&#x299E;': '\\measuredangle',
    '&#x299D;': '\\measuredangle',
    '&#x299C;': '\\perp',
    '&#x299B;': '\\measuredangle',
    '&#x299A;': '',
    '&#x2999;': '\\vdots',
    '&#x297F;': '',
    '&#x297E;': '',
    '&#x297D;': '\\prec',
    '&#x297C;': '\\succ',
    '&#x297B;': '\\underset{\\rightarrow}{\\supset}',
    '&#x297A;': '',
    '&#x2979;': '\\underset{\\rightarrow}{\\subset}',
    '&#x2978;': '\\underset{\\rightarrow}{>}',
    '&#x2977;': '',
    '&#x2976;': '\\underset{\\leftarrow}{<}',
    '&#x2975;': '\\underset{\\approx}{\\rightarrow}',
    '&#x2974;': '\\underset{\\sim}{\\rightarrow}',
    '&#x2973;': '\\underset{\\sim}{\\leftarrow}',
    '&#x2972;': '\\overset{\\sim}{\\rightarrow}',
    '&#x2971;': '\\overset{=}{\\rightarrow}',
    '&#x2970;': '',
    '&#x296F;': '',
    '&#x296E;': '',
    '&#x296D;': '\\overline{\\rightharpoondown}',
    '&#x296C;': '\\underline{\\rightharpoonup}',
    '&#x296B;': '\\overline{\\leftharpoondown}',
    '&#x296A;': '\\underline{\\leftharpoonup}',
    '&#x2969;': '\\rightleftharpoons',
    '&#x2968;': '\\rightleftharpoons',
    '&#x2967;': '\\rightleftharpoons',
    '&#x2966;': '\\rightleftharpoons',
    '&#x2965;': '\\Downarrow',
    '&#x2964;': '\\Rightarrow',
    '&#x2963;': '\\Uparrow',
    '&#x2962;': '\\Leftarrow',
    '&#x2961;': '\\downarrow',
    '&#x2960;': '\\uparrow',
    '&#x295F;': '\\rightarrow',
    '&#x295E;': '\\leftarrow',
    '&#x295D;': '\\downarrow',
    '&#x295C;': '\\uparrow',
    '&#x295B;': '\\rightarrow',
    '&#x295A;': '\\leftarrow',
    '&#x2959;': '\\downarrow',
    '&#x2958;': '\\uparrow',
    '&#x2957;': '\\rightarrow',
    '&#x2956;': '\\leftarrow',
    '&#x2955;': '\\downarrow',
    '&#x2954;': '\\uparrow',
    '&#x2953;': '\\rightarrow',
    '&#x2952;': '\\leftarrow',
    '&#x2951;': '\\updownarrow',
    '&#x2950;': '\\leftrightarrow',
    '&#x294F;': '\\updownarrow',
    '&#x294E;': '\\leftrightarrow',
    '&#x294D;': '\\updownarrow',
    '&#x294C;': '\\updownarrow',
    '&#x294B;': '\\leftrightarrow',
    '&#x294A;': '\\leftrightarrow',
    '&#x2949;': '',
    '&#x2948;': '\\leftrightarrow',
    '&#x2947;': '\\nrightarrow',
    '&#x2946;': '',
    '&#x2945;': '',
    '&#x2944;': '\\rightleftarrows',
    '&#x2943;': '\\leftrightarrows',
    '&#x2942;': '\\rightleftarrows',
    '&#x2941;': '\\circlearrowright',
    '&#x2940;': '\\circlearrowleft',
    '&#x293F;': '\\rightarrow',
    '&#x293E;': '\\leftarrow',
    '&#x293D;': '',
    '&#x293C;': '',
    '&#x293B;': '',
    '&#x293A;': '',
    '&#x2939;': '',
    '&#x2938;': '',
    '&#x2937;': '\\Rsh',
    '&#x2936;': '\\Lsh',
    '&#x2935;': '\\downarrow',
    '&#x2934;': '\\uparrow',
    '&#x2933;': '\\leadsto',
    '&#x2932;': '',
    '&#x2931;': '',
    '&#x2930;': '',
    '&#x292F;': '',
    '&#x292E;': '',
    '&#x292D;': '',
    '&#x292C;': '\\times',
    '&#x292B;': '\\times',
    '&#x292A;': '',
    '&#x2929;': '',
    '&#x2928;': '',
    '&#x2927;': '',
    '&#x2926;': '',
    '&#x2925;': '',
    '&#x2924;': '',
    '&#x2923;': '',
    '&#x2922;': '',
    '&#x2921;': '',
    '&#x2920;': '\\mapsto\\cdot',
    '&#x291F;': '\\cdot\\leftarrow',
    '&#x291E;': '\\rightarrow\\cdot',
    '&#x291D;': '\\leftarrow',
    '&#x291C;': '\\rightarrow',
    '&#x291B;': '\\leftarrow',
    '&#x291A;': '\\rightarrow',
    '&#x2919;': '\\leftarrow',
    '&#x2918;': '\\rightarrow',
    '&#x2917;': '\\rightarrow',
    '&#x2916;': '\\rightarrow',
    '&#x2915;': '\\rightarrow',
    '&#x2914;': '\\rightarrow',
    '&#x2913;': '\\downarrow',
    '&#x2912;': '\\uparrow',
    '&#x2911;': '\\rightarrow',
    '&#x2910;': '\\rightarrow',
    '&#x290F;': '\\rightarrow',
    '&#x290E;': '\\leftarrow',
    '&#x290D;': '\\rightarrow',
    '&#x290C;': '\\leftarrow',
    '&#x290B;': '\\Downarrow',
    '&#x290A;': '\\Uparrow',
    '&#x2909;': '\\uparrow',
    '&#x2908;': '\\downarrow',
    '&#x2907;': '\\Rightarrow',
    '&#x2906;': '\\Leftarrow',
    '&#x2905;': '\\mapsto',
    '&#x2904;': '\\nLeftrightarrow',
    '&#x2903;': '\\nRightarrow',
    '&#x2902;': '\\nLeftarrow',
    '&#x2901;': '\\rightsquigarrow',
    '&#x2900;': '\\rightsquigarrow',
    '&#x27FF;': '\\rightsquigarrow',
    '&#x27FE;': '\\Rightarrow',
    '&#x27FD;': '\\Leftarrow',
    '&#x27FC;': '\\mapsto',
    '&#x27FB;': '\\leftarrow',
    '&#x27FA;': '\\Longleftrightarrow',
    '&#x27F9;': '\\Longrightarrow',
    '&#x27F8;': '\\Longleftarrow',
    '&#x27F7;': '\\leftrightarrow',
    '&#x27F6;': '\\rightarrow',
    '&#x27F5;': '\\leftarrow',
    '&#x27F1;': '\\Downarrow',
    '&#x27F0;': '\\Uparrow',
    '&#x22B8;': '\\rightarrow',
    '&#x21FF;': '\\leftrightarrow',
    '&#x21FE;': '\\rightarrow',
    '&#x21FD;': '\\leftarrow',
    '&#x21FC;': '\\nleftrightarrow',
    '&#x21FB;': '\\nrightarrow',
    '&#x21FA;': '\\nleftarrow',
    '&#x21F9;': '\\nleftrightarrow',
    '&#x21F8;': '\\nrightarrow',
    '&#x21F7;': '\\nleftarrow',
    '&#x21F6;': '\\Rrightarrow',
    '&#x21F5;': '',
    '&#x21F4;': '\\rightarrow',
    '&#x21F3;': '\\Updownarrow',
    '&#x21F2;': '\\searrow',
    '&#x21F1;': '\\nwarrow',
    '&#x21F0;': '\\Leftarrow',
    '&#x21EF;': '\\Uparrow',
    '&#x21EE;': '\\Uparrow',
    '&#x21ED;': '\\Uparrow',
    '&#x21EC;': '\\Uparrow',
    '&#x21EB;': '\\Uparrow',
    '&#x21EA;': '\\Uparrow',
    '&#x21E9;': '\\Downarrow',
    '&#x21E8;': '\\Rightarrow',
    '&#x21E7;': '\\Uparrow',
    '&#x21E6;': '\\Leftarrow',
    '&#x21E5;': '\\rightarrow',
    '&#x21E4;': '\\leftarrow',
    '&#x21E3;': '\\downarrow',
    '&#x21E2;': '\\rightarrow',
    '&#x21E1;': '\\uparrow',
    '&#x21E0;': '\\leftarrow',
    '&#x21DF;': '\\downarrow',
    '&#x21DE;': '\\uparrow',
    '&#x21DD;': '\\rightsquigarrow',
    '&#x21DC;': '\\leftarrow',
    '&#x21DB;': '\\Rrightarrow',
    '&#x21DA;': '\\Lleftarrow',
    '&#x21D9;': '\\swarrow',
    '&#x21D8;': '\\searrow',
    '&#x21D7;': '\\nearrow',
    '&#x21D6;': '\\nwarrow',
    '&#x21D5;': '\\Updownarrow',
    '&#x21D4;': '\\Leftrightarrow',
    '&#x21D3;': '\\Downarrow',
    '&#x21D2;': '\\Rightarrow',
    '&#x21D1;': '\\Uparrow',
    '&#x21D0;': '\\Leftarrow',
    '&#x21CF;': '\\nRightarrow',
    '&#x21CE;': '\\nLeftrightarrow',
    '&#x21CD;': '\\nLeftarrow',
    '&#x21CC;': '\\rightleftharpoons',
    '&#x21CB;': '\\leftrightharpoons',
    '&#x21CA;': '\\downdownarrows',
    '&#x21C9;': '\\rightrightarrows',
    '&#x21C8;': '\\upuparrows',
    '&#x21C7;': '\\leftleftarrows',
    '&#x21C6;': '\\leftrightarrows',
    '&#x21C5;': '',
    '&#x21C4;': '\\rightleftarrows',
    '&#x21C3;': '\\downharpoonleft',
    '&#x21C2;': '\\downharpoonright',
    '&#x21C1;': '\\rightharpoondown',
    '&#x21C0;': '\\rightharpoonup',
    '&#x21BF;': '\\upharpoonleft',
    '&#x21BE;': '\\upharpoonright',
    '&#x21BD;': '\\leftharpoondown',
    '&#x21BC;': '\\leftharpoonup',
    '&#x21BB;': '\\circlearrowright',
    '&#x21BA;': '\\circlearrowleft',
    '&#x21B9;': '\\leftrightarrows',
    '&#x21B8;': '\\overline{\\nwarrow}',
    '&#x21B7;': '\\curvearrowright',
    '&#x21B6;': '\\curvearrowleft',
    '&#x21B5;': '\\swarrow',
    '&#x21B4;': '\\searrow',
    '&#x21B3;': '\\Rsh',
    '&#x21B2;': '\\Lsh',
    '&#x21B1;': '\\Rsh',
    '&#x21B0;': '\\Lsh',
    '&#x21AF;': '\\swarrow',
    '&#x21AE;': '',
    '&#x21AD;': '\\leftrightsquigarrow',
    '&#x21AC;': '\\looparrowright',
    '&#x21AB;': '\\looparrowleft',
    '&#x21AA;': '\\hookrightarrow',
    '&#x21A9;': '\\hookleftarrow',
    '&#x21A8;': '\\underline{\\updownarrow}',
    '&#x21A7;': '\\downarrow',
    '&#x21A6;': '\\rightarrowtail',
    '&#x21A5;': '\\uparrow',
    '&#x21A4;': '\\leftarrowtail',
    '&#x21A3;': '\\rightarrowtail',
    '&#x21A2;': '\\leftarrowtail',
    '&#x21A1;': '\\downarrow',
    '&#x21A0;': '\\twoheadrightarrow',
    '&#x219F;': '\\uparrow',
    '&#x219E;': '\\twoheadleftarrow',
    '&#x219D;': '\\nearrow',
    '&#x219C;': '\\nwarrow',
    '&#x219B;': '',
    '&#x219A;': '',
    '&#x2199;': '\\swarrow',
    '&#x2198;': '\\searrow',
    '&#x2197;': '\\nearrow',
    '&#x2196;': '\\nwarrow',
    '&#x2195;': '\\updownarrow',
    '&#x2194;': '\\leftrightarrow',
    '&#x2193;': '\\downarrow',
    '&#x2192;': '\\rightarrow',
    '&#x2191;': '\\uparrow',
    '&#x2190;': '\\leftarrow',
    '|||': '\\left|||\\right.',
    '||': '\\left||\\right.',
    '|': '\\left|\\right.',
    '&#x2AFE;': '',
    '&#x2AFD;': '//',
    '&#x2AFB;': '///',
    '&#x2AFA;': '',
    '&#x2AF9;': '',
    '&#x2AF8;': '',
    '&#x2AF7;': '',
    '&#x2AF6;': '\\vdots',
    '&#x2AF5;': '',
    '&#x2AF4;': '',
    '&#x2AF3;': '',
    '&#x2AF2;': '\\nparallel',
    '&#x2AF1;': '',
    '&#x2AF0;': '',
    '&#x2AEF;': '',
    '&#x2AEE;': '\\bcancel{\\mid}',
    '&#x2AED;': '',
    '&#x2AEC;': '',
    '&#x2AEB;': '',
    '&#x2AEA;': '',
    '&#x2AE9;': '',
    '&#x2AE8;': '\\underline{\\perp}',
    '&#x2AE7;': '\\overline{\\top}',
    '&#x2AE6;': '',
    '&#x2AE5;': '',
    '&#x2AE4;': '',
    '&#x2AE3;': '',
    '&#x2AE2;': '',
    '&#x2AE1;': '',
    '&#x2AE0;': '\\perp',
    '&#x2ADF;': '\\top',
    '&#x2ADE;': '\\dashv',
    '&#x2ADD;&#x338;': '',
    '&#x2ADD;': '',
    '&#x2ADB;': '\\pitchfork',
    '&#x2ADA;': '',
    '&#x2AD9;': '',
    '&#x2AD8;': '',
    '&#x2AD7;': '',
    '&#x2AD6;': '',
    '&#x2AD5;': '',
    '&#x2AD4;': '',
    '&#x2AD3;': '',
    '&#x2AD2;': '',
    '&#x2AD1;': '',
    '&#x2AD0;': '',
    '&#x2ACF;': '',
    '&#x2ACE;': '',
    '&#x2ACD;': '',
    '&#x2ACC;': '\\underset{\\neq}{\\supset}',
    '&#x2ACB;': '\\underset{\\neq}{\\subset}',
    '&#x2ACA;': '\\underset{\\approx}{\\supset}',
    '&#x2AC9;': '\\underset{\\approx}{\\subset}',
    '&#x2AC8;': '\\underset{\\sim}{\\supset}',
    '&#x2AC7;': '\\underset{\\sim}{\\subset}',
    '&#x2AC6;': '\\supseteqq',
    '&#x2AC5;': '\\subseteqq',
    '&#x2AC4;': '\\dot{\\supseteq}',
    '&#x2AC3;': '\\dot{\\subseteq}',
    '&#x2AC2;': '\\underset{\\times}{\\supset}',
    '&#x2AC1;': '\\underset{\\times}{\\subset}',
    '&#x2AC0;': '\\underset{+}{\\supset}',
    '&#x2ABF;': '\\underset{+}{\\subset}',
    '&#x2ABE;': '',
    '&#x2ABD;': '',
    '&#x2ABC;': '\\gg ',
    '&#x2ABB;': '\\ll',
    '&#x2ABA;': '\\underset{\\cancel{\\approx}}{\\succ}',
    '&#x2AB9;': '\\underset{\\cancel{\\approx}}{\\prec}',
    '&#x2AB8;': '\\underset{\\approx}{\\succ}',
    '&#x2AB7;': '\\underset{\\approx}{\\prec}',
    '&#x2AB6;': '\\underset{\\cancel{=}}{\\succ}',
    '&#x2AB5;': '\\underset{\\cancel{=}}{\\prec}',
    '&#x2AB4;': '\\underset{=}{\\succ}',
    '&#x2AB3;': '\\underset{=}{\\prec}',
    '&#x2AB2;': '',
    '&#x2AB1;': '',
    '&#x2AAE;': '',
    '&#x2AAD;': '\\underline{\\hcancel{>}}',
    '&#x2AAC;': '\\underline{\\hcancel{>}}',
    '&#x2AAB;': '\\hcancel{>}',
    '&#x2AAA;': '\\hcancel{<}',
    '&#x2AA9;': '',
    '&#x2AA8;': '',
    '&#x2AA7;': '\\vartriangleright',
    '&#x2AA6;': '\\vartriangleleft',
    '&#x2AA5;': '><',
    '&#x2AA4;': '><',
    '&#x2AA3;': '\\underline{\\ll}',
    '&#x2AA2;&#x338;': '\\cancel{\\gg}',
    '&#x2AA2;': '\\gg',
    '&#x2AA1;&#x338;': '\\cancel{\\ll}',
    '&#x2AA1;': '\\ll',
    '&#x2AA0;': '\\overset{\\sim}{\\geqq}',
    '&#x2A9F;': '\\overset{\\sim}{\\leqq}',
    '&#x2A9E;': '\\overset{\\sim}{>}',
    '&#x2A9D;': '\\overset{\\sim}{<}',
    '&#x2A9C;': '',
    '&#x2A9B;': '',
    '&#x2A9A;': '\\overset{=}{>}',
    '&#x2A99;': '\\overset{=}{<}',
    '&#x2A98;': '',
    '&#x2A97;': '',
    '&#x2A96;': '',
    '&#x2A95;': '',
    '&#x2A94;': '',
    '&#x2A93;': '',
    '&#x2A92;': '\\underset{=}{\\gtrless}',
    '&#x2A91;': '\\underset{=}{\\lessgtr}',
    '&#x2A90;': '\\underset{<}{\\gtrsim}',
    '&#x2A8F;': '\\underset{>}{\\lesssim}',
    '&#x2A8E;': '\\underset{\\simeq}{>}',
    '&#x2A8D;': '\\underset{\\simeq}{<}',
    '&#x2A8C;': '\\gtreqqless',
    '&#x2A8B;': '\\lesseqqgtr',
    '&#x2A8A;': '\\underset{\\cancel{\\approx}}{>}',
    '&#x2A89;': '\\underset{\\approx}{<}',
    '&#x2A86;': '\\underset{\\approx}{>}',
    '&#x2A85;': '\\underset{\\approx}{<}',
    '&#x2A84;': '',
    '&#x2A83;': '',
    '&#x2A82;': '',
    '&#x2A81;': '',
    '&#x2A80;': '',
    '&#x2A7F;': '',
    '&#x2A7E;&#x338;': '\\bcancel{\\geq}',
    '&#x2A7E;': '\\geq',
    '&#x2A7D;&#x338;': '\\bcancel{\\leq}',
    '&#x2A7D;': '\\leq',
    '&#x2A7C;': '',
    '&#x2A7B;': '',
    '&#x2A7A;': '',
    '&#x2A79;': '',
    '&#x2A78;': '\\overset{\\dots}{\\equiv}',
    '&#x2A77;': '',
    '&#x2A76;': '===',
    '&#x2A75;': '==',
    '&#x2A74;': '::=',
    '&#x2A73;': '',
    '&#x2A72;': '\\underset{=}{+}',
    '&#x2A71;': '\\overset{=}{+}',
    '&#x2A70;': '\\overset{\\approx}{=}',
    '&#x2A6F;': '\\overset{\\wedge}{=}',
    '&#x2A6E;': '\\overset{*}{=}',
    '&#x2A6D;': '\\dot{\\approx}',
    '&#x2A6C;': '',
    '&#x2A6B;': '',
    '&#x2A6A;': '\\dot{\\sim}',
    '&#x2A69;': '',
    '&#x2A68;': '',
    '&#x2A67;': '\\dot{\\equiv}',
    '&#x2A66;': '\\underset{\\cdot}{=}',
    '&#x2A65;': '',
    '&#x2A64;': '',
    '&#x2A63;': '\\underset{=}{\\vee}',
    '&#x2A62;': '\\overset{=}{\\vee}',
    '&#x2A61;': 'ul(vv)',
    '&#x2A60;': '\\underset{=}{\\wedge}',
    '&#x2A5F;': '\\underline{\\wedge}',
    '&#x2A5E;': '\\overset{=}{\\wedge}',
    '&#x2A5D;': '\\hcancel{\\vee}',
    '&#x2A5C;': '\\hcancel{\\wedge}',
    '&#x2A5B;': '',
    '&#x2A5A;': '',
    '&#x2A59;': '',
    '&#x2A58;': '\\vee',
    '&#x2A57;': '\\wedge',
    '&#x2A56;': '',
    '&#x2A55;': '',
    '&#x2A54;': '',
    '&#x2A53;': '',
    '&#x2A52;': '\\dot{\\vee}',
    '&#x2A51;': '\\dot{\\wedge}',
    '&#x2A50;': '',
    '&#x2A4F;': '',
    '&#x2A4E;': '',
    '&#x2A4D;': '\\overline{\\cap}',
    '&#x2A4C;': '\\overline{\\cup}',
    '&#x2A4B;': '',
    '&#x2A4A;': '',
    '&#x2A49;': '',
    '&#x2A48;': '',
    '&#x2A47;': '',
    '&#x2A46;': '',
    '&#x2A45;': '',
    '&#x2A44;': '',
    '&#x2A43;': '\\overline{\\cap}',
    '&#x2A42;': '\\overline{\\cup}',
    '&#x2A41;': '',
    '&#x2A40;': '',
    '&#x2A3E;': '',
    '&#x2A3D;': '\\llcorner',
    '&#x2A3C;': '\\lrcorner',
    '&#x2A3B;': '',
    '&#x2A3A;': '',
    '&#x2A39;': '',
    '&#x2A38;': '',
    '&#x2A37;': '',
    '&#x2A36;': '\\hat{\\otimes}',
    '&#x2A35;': '',
    '&#x2A34;': '',
    '&#x2A33;': '',
    '&#x2A32;': '\\underline{\\times}',
    '&#x2A31;': '\\underline{\\times}',
    '&#x2A30;': '\\dot{\\times}',
    '&#x2A2E;': '',
    '&#x2A2D;': '',
    '&#x2A2C;': '',
    '&#x2A2B;': '',
    '&#x2A2A;': '',
    '&#x2A29;': '',
    '&#x2A28;': '',
    '&#x2A27;': '',
    '&#x2A26;': '\\underset{\\sim}{+}',
    '&#x2A25;': '\\underset{\\circ}{+}',
    '&#x2A24;': '\\overset{\\sim}{+}',
    '&#x2A23;': '\\hat{+}',
    '&#x2A22;': '\\dot{+}',
    '&#x2A21;': '\\upharpoonright',
    '&#x2A20;': '>>',
    '&#x2A1F;': '',
    '&#x2A1E;': '\\triangleleft',
    '&#x2A1D;': '\\bowtie',
    '&#x29FF;': '',
    '&#x29FE;': '+',
    '&#x29FB;': '\\hcancel{|||}',
    '&#x29FA;': '\\hcancel{||}',
    '&#x29F9;': '\\backslash',
    '&#x29F8;': '/',
    '&#x29F7;': 'hcancel{\backslash}',
    '&#x29F6;': '',
    '&#x29F5;': '\\backslash',
    '&#x29F2;': '\\Phi',
    '&#x29F1;': '',
    '&#x29F0;': '',
    '&#x29EE;': '',
    '&#x29ED;': '',
    '&#x29EC;': '',
    '&#x29EB;': '\\lozenge',
    '&#x29EA;': '',
    '&#x29E9;': '',
    '&#x29E8;': '',
    '&#x29E7;': '\\ddagger',
    '&#x29E2;': '\\sqcup\\sqcup',
    '&#x29E1;': '',
    '&#x29E0;': '\\square',
    '&#x29DE;': '',
    '&#x29DD;': '',
    '&#x29DC;': '',
    '&#x29DB;': '\\{\\{',
    '&#x29D9;': '\\{',
    '&#x29D8;': '\\}',
    '&#x29D7;': '',
    '&#x29D6;': '',
    '&#x29D5;': '\\bowtie',
    '&#x29D4;': '\\bowtie',
    '&#x29D3;': '\\bowtie',
    '&#x29D2;': '\\bowtie',
    '&#x29D1;': '\\bowtie',
    '&#x29D0;&#x338;': '| \\not\\triangleright',
    '&#x29D0;': '| \\triangleright',
    '&#x29CF;&#x338;': '\\not\\triangleleft |',
    '&#x29CF;': '\\triangleleft |',
    '&#x29CE;': '',
    '&#x29CD;': '\\triangle',
    '&#x29CC;': '',
    '&#x29CB;': '\\underline{\\triangle}',
    '&#x29CA;': '\\dot{\\triangle}',
    '&#x29C9;': '',
    '&#x29C8;': '\\boxed{\\circ}',
    '&#x29C7;': '\\boxed{\\circ}',
    '&#x29C6;': '\\boxed{\\rightarrow}',
    '&#x29C5;': '\\bcancel{\\square}',
    '&#x29C4;': '\\cancel{\\square}',
    '&#x29C3;': '\\odot',
    '&#x29C2;': '\\odot',
    '&#x29BF;': '\\odot',
    '&#x29BE;': '\\odot',
    '&#x29BD;': '\\varnothing',
    '&#x29BC;': '\\oplus',
    '&#x29BB;': '\\otimes',
    '&#x29BA;': '',
    '&#x29B9;': '\\varnothing',
    '&#x29B8;': '\\varnothing',
    '&#x29B7;': '\\ominus',
    '&#x29B6;': '\\ominus',
    '&#x29B5;': '\\ominus',
    '&#x29B4;': '\\vec{\\varnothing}',
    '&#x29B3;': '\\vec{\\varnothing}',
    '&#x29B2;': '\\dot{\\varnothing}',
    '&#x29B1;': '\\overline{\\varnothing}',
    '&#x29B0;': '\\varnothing',
    '&#x29AF;': '',
    '&#x29AE;': '',
    '&#x29AD;': '',
    '&#x29AC;': '',
    '&#x29AB;': '',
    '&#x29AA;': '',
    '&#x29A9;': '',
    '&#x29A8;': '',
    '&#x29A7;': '',
    '&#x29A6;': '',
    '&#x29A5;': '',
    '&#x29A4;': '',
    '&#x29A3;': '',
    '&#x29A2;': '',
    '&#x29A1;': '\\not\\lor',
    '&#x29A0;': '\\bcancel{>}',
    '&#x2982;': ':',
    '&#x2981;': '\\circ',
    '&#x2758;': '|',
    '&#x25B2;': '\\bigtriangleup',
    '&#x22FF;': '\\Epsilon',
    '&#x22FE;': '\\overline{\\ni}',
    '&#x22FD;': '\\overline{\\ni}',
    '&#x22FC;': '\\in',
    '&#x22FB;': '\\in',
    '&#x22FA;': '\\in',
    '&#x22F9;': '\\underline{\\in}',
    '&#x22F8;': '\\underline{\\in}',
    '&#x22F7;': '\\overline{\\in}',
    '&#x22F6;': '\\overline{\\in}',
    '&#x22F5;': '\\dot{\\in}',
    '&#x22F4;': '\\in',
    '&#x22F3;': '\\in',
    '&#x22F2;': '\\in',
    '&#x22F0;': '\\ddots',
    '&#x22E9;': '\\underset{\\sim}{\\succ}',
    '&#x22E8;': '\\underset{\\sim}{\\prec}',
    '&#x22E7;': '\\underset{\\not\\sim}{>}',
    '&#x22E6;': '\\underset{\\not\\sim}{<}',
    '&#x22E5;': '\\not\\sqsupseteq',
    '&#x22E4;': '\\not\\sqsubseteq',
    '&#x22E3;': '\\not\\sqsupseteq',
    '&#x22E2;': '\\not\\sqsubseteq',
    '&#x22E1;': '\\nsucc',
    '&#x22E0;': '\\nprec',
    '&#x22DF;': '\\succ',
    '&#x22DE;': '\\prec',
    '&#x22DD;': '\\overline{>}',
    '&#x22DC;': '\\overline{<}',
    '&#x22DB;': '\\underset{>}{\\leq}',
    '&#x22DA;': '\\underset{<}{\\geq}',
    '&#x22D5;': '\\#',
    '&#x22D3;': '\\cup',
    '&#x22D2;': '\\cap',
    '&#x22D1;': '\\supset',
    '&#x22D0;': '\\subset',
    '&#x22CF;': '\\wedge',
    '&#x22CE;': '\\vee',
    '&#x22CD;': '\\simeq',
    '&#x22C8;': '\\bowtie',
    '&#x22C7;': '\\ast',
    '&#x22C6;': '\\star',
    '&#x22C4;': '\\diamond',
    '&#x22BF;': '\\triangle',
    '&#x22BE;': '\\measuredangle',
    '&#x22BD;': '\\overline{\\lor}',
    '&#x22BC;': '\\overline{\\land}',
    '&#x22BB;': '\\underline{\\lor}',
    '&#x22BA;': '\\top',
    '&#x22B9;': '',
    '&#x22B7;': '\\circ\\multimap',
    '&#x22B6;': '\\circ\\multimap',
    '&#x22B3;': '\\triangleright',
    '&#x22B2;': '\\triangleleft',
    '&#x22B1;': '\\succ',
    '&#x22B0;': '\\prec',
    '&#x22AB;': '|\\models',
    '&#x22AA;': '|\\models',
    '&#x22A7;': '\\models',
    '&#x22A6;': '\\vdash',
    '&#x229D;': '\\ominus',
    '&#x229C;': '\\ominus',
    '&#x229B;': '\\odot',
    '&#x229A;': '\\odot',
    '&#x2294;': '\\sqcup',
    '&#x2293;': '\\sqcap',
    '&#x2292;': '\\sqsupseteq',
    '&#x2291;': '\\sqsubseteq',
    '&#x2290;&#x338;': '\\not\\sqsupset',
    '&#x2290;': '\\sqsupset',
    '&#x228F;&#x338;': '\\not\\sqsubset',
    '&#x228F;': '\\sqsubset',
    '&#x228E;': '\\cup',
    '&#x228D;': '\\cup',
    '&#x228C;': '\\cup',
    '&#x227F;&#x338;': '\\not\\succsim',
    '&#x227F;': '\\succsim',
    '&#x227E;': '\\precsim',
    '&#x2279;': '\\not\\overset{>}{<}',
    '&#x2278;': '\\not\\overset{>}{<}',
    '&#x2277;': '\\overset{>}{<}',
    '&#x2276;': '\\overset{<}{>}',
    '&#x2275;': '\\not\\geg',
    '&#x2274;': '\\not\\leq',
    '&#x2273;': '\\geg',
    '&#x2272;': '\\leq',
    '&#x226C;': '',
    '&#x2267;': '\\geg',
    '&#x2266;&#x338;': '\\not\\leq',
    '&#x2266;': '\\leq',
    '&#x2263;': '\\overset{=}{=} ',
    '&#x225E;': '\\overset{m}{=} ',
    '&#x225D;': '\\overset{def}{=}',
    '&#x2258;': '=',
    '&#x2256;': '=',
    '&#x2255;': '=:',
    '&#x2253;': '\\doteq',
    '&#x2252;': '\\doteq',
    '&#x2251;': '\\doteq',
    '&#x2250;': '\\doteq',
    '&#x224F;&#x338;': '',
    '&#x224F;': '',
    '&#x224E;&#x338;': '',
    '&#x224E;': '',
    '&#x224C;': '\\approx',
    '&#x224B;': '\\approx',
    '&#x224A;': '\\approx',
    '&#x2242;&#x338;': '\\neq',
    '&#x2242;': '=',
    '&#x223F;': '\\sim',
    '&#x223E;': '\\infty',
    '&#x223D;&#x331;': '\\sim',
    '&#x223D;': '\\sim',
    '&#x223B;': '\\sim',
    '&#x223A;': ':-:',
    '&#x2239;': '-:',
    '&#x2238;': '\\bot',
    '&#x2237;': '::',
    '&#x2236;': ':',
    '&#x2223;': '|',
    '&#x221F;': '\\llcorner',
    '&#x2219;': '\\cdot',
    '&#x2218;': '\\circ',
    '&#x2217;': '*',
    '&#x2215;': '/',
    '&#x220E;': '\\square',
    '&#x220D;': '\\ni',
    '&#x220A;': '\\in',
    '&#x2206;': '\\Delta',
    '&#x2044;': '/',
    '&#x2AB0;&#x338;': '\\nsucceq',
    '&#x2AB0;': '\\succeq',
    '&#x2AAF;&#x338;': '\\npreceq',
    '&#x2AAF;': '\\preceq',
    '&#x2A88;': '\\ngeqslant',
    '&#x2A87;': '\\nleqslant',
    '&#x29F3;': '\\Phi',
    '&#x29E6;': '\\models',
    '&#x29E5;': '\\not\\equiv',
    '&#x29E4;': '\\approx\\neq',
    '&#x29E3;': '\\neq',
    '&#x29C1;': '\\circle',
    '&#x29C0;': '\\circle',
    '&#x25E6;': '\\circle',
    '&#x25D7;': '\\circle',
    '&#x25D6;': '\\circle',
    '&#x25CF;': '\\circle',
    '&#x25CE;': '\\circledcirc',
    '&#x25CD;': '\\circledcirc',
    '&#x25CC;': '\\circledcirc',
    '&#x25C9;': '\\circledcirc',
    '&#x25C8;': '\\diamond',
    '&#x25C7;': '\\diamond',
    '&#x25C6;': '\\diamond',
    '&#x25C5;': '\\triangleleft',
    '&#x25C4;': '\\triangleleft',
    '&#x25C3;': '\\triangleleft',
    '&#x25C2;': '\\triangleleft',
    '&#x25C1;': '\\triangleleft',
    '&#x25C0;': '\\triangleleft',
    '&#x25BF;': '\\triangledown',
    '&#x25BE;': '\\triangledown',
    '&#x25BD;': '\\triangledown',
    '&#x25BC;': '\\triangledown',
    '&#x25B9;': '\\triangleright',
    '&#x25B8;': '\\triangleright',
    '&#x25B7;': '\\triangleright',
    '&#x25B6;': '\\triangleright',
    '&#x25B5;': '\\triangle',
    '&#x25B4;': '\\triangle',
    '&#x25B3;': '\\triangle',
    '&#x25B1;': '\\square',
    '&#x25B0;': '\\square',
    '&#x25AF;': '\\square',
    '&#x25AE;': '\\square',
    '&#x25AD;': '\\square',
    '&#x25AB;': '\\square',
    '&#x25AA;': '\\square',
    '&#x25A1;': '\\square',
    '&#x25A0;': '\\square',
    '&#x22ED;': '\\not\\triangleright',
    '&#x22EC;': '\\not\\triangleleft',
    '&#x22EB;': '\\not\\triangleright',
    '&#x22EA;': '\\not\\triangleleft',
    '&#x22D9;': '\\ggg',
    '&#x22D8;': '\\lll',
    '&#x22D7;': '*>',
    '&#x22D6;': '<*',
    '&#x22D4;': '\\pitchfork',
    '&#x22CC;': '',
    '&#x22CB;': '',
    '&#x22CA;': '\\rtimes',
    '&#x22C9;': '\\ltimes',
    '&#x22B5;': '\\triangleright',
    '&#x22B4;': '',
    '&#x22A5;': '\\bot',
    '&#x2281;': '\\nsucc',
    '&#x2280;': '\\preceq',
    '&#x227D;': '\\succeq',
    '&#x227C;': '\\preceq',
    '&#x227B;': '\\succ',
    '&#x227A;': '\\prec',
    '&#x2271;': '\\geq/',
    '&#x2270;': '\\leq/',
    '&#x226D;': '\\neq',
    '&#x226B;&#x338;': '\\not\\gg',
    '&#x226B;': '\\gg',
    '&#x226A;&#x338;': '\\not\\ll',
    '&#x226A;': '\\ll',
    '&#x2269;': '\\ngeqslant',
    '&#x2268;': '\\nleqslant',
    '&#x2261;': '\\equiv',
    '&#x225F;': '\\doteq',
    '&#x225C;': '\\triangleq',
    '&#x225B;': '\\doteq',
    '&#x225A;': '\\triangleq',
    '&#x2259;': '\\triangleq',
    '&#x2257;': '\\doteq',
    '&#x2254;': ':=',
    '&#x224D;': '\\asymp',
    '&#x2247;': '\\ncong',
    '&#x2246;': '\\ncong',
    '&#x2245;': '\\cong',
    '&#x2244;': '\\not\\simeq',
    '&#x2243;': '\\simeq',
    '&#x2241;': '\\not\\sim',
    '&#x2226;': '\\not\\parallel',
    '&#x2225;': '\\parallel',
    '&#x2224;': '\\not|',
    '&#x221D;': '\\propto',
    '==': '==',
    '=': '=',
    ':=': ':=',
    '/=': '=',
    '-=': '-=',
    '+=': '+=',
    '*=': '*=',
    '!=': '!=',
    '&#x2260;': '\\neq',
    '&#x2262;': '\\equiv /',
    '&#x2249;': '\\approx /',
    '&#x223C;': 'sim',
    '&#x2248;': '\\approx',
    '&#x226E;': '</',
    '&lt;': '<',
    '&#x226F;': '>/',
    '>=': '>=',
    '>': '>',
    '&#x2265;': '\\geq',
    '&#x2264;': '\\leq',
    '&lt;=': '<=',
    '&#x228B;': '\\supsetneq',
    '&#x228A;': '\\subsetneq',
    '&#x2289;': '\\nsupseteq',
    '&#x2288;': '\\nsubseteq',
    '&#x2287;': '\\supseteq',
    '&#x2286;': '\\subseteq',
    '&#x2285;': '\\not\\supset',
    '&#x2284;': '\\not\\subset',
    '&#x2283;&#x20D2;': '\\supset |',
    '&#x2283;': '\\supset',
    '&#x2282;&#x20D2;': '\\subset |',
    '&#x2282;': '\\subset',
    '&#x220C;': '\\not\\in',
    '&#x2209;': '\\notin',
    '&#x2208;': '\\in',
    '&#x2201;': 'C',
    '&#x2204;': '\\nexists',
    '&#x2203;': '\\exists',
    '&#x2200;': '\\forall',
    '&#x2227;': '\\land',
    '&amp;&amp;': '\\&\\&',
    '&#x2228;': '\\lor',
    '&#x22AF;': '\\cancel{\\vDash}',
    '&#x22AE;': '\\cancel{\\Vdash}',
    '&#x22AD;': '\\nvDash',
    '&#x22AC;': '\\nvDash',
    '&#x22A9;': '\\Vdash',
    '&#x22A8;': '\\vDash',
    '&#x22A4;': '\\top',
    '&#x22A3;': '\\dashv',
    '&#x22A2;': '\\vdash',
    '&#x220B;': '\\ni',
    '&#x22F1;': '\\ddots',
    '&#x22EF;': '\\hdots',
    '&#x22EE;': '\\vdots',
    '&#x2026;': '\\hdots',
    '&#x3F6;': '\\ni',
    ':': ':',
    '...': '\\cdots',
    '..': '..',
    '->': '->',
    '&#x2235;': '\\because',
    '&#x2234;': '\\therefore ',
    '&#x2063;': '',
    ',': ',',
    ';': ';',
    '&#x29FD;': '\\}',
    '&#x29FC;': '\\{',
    '&#x2998;': '\\]',
    '&#x2997;': '\\[',
    '&#x2996;': '\\ll',
    '&#x2995;': '\\gg',
    '&#x2994;': '\\gg',
    '&#x2993;': '\\ll',
    '&#x2992;': '\\gg',
    '&#x2991;': '\\ll',
    '&#x2990;': '\\]',
    '&#x298F;': '\\]',
    '&#x298E;': '\\]',
    '&#x298D;': '\\[',
    '&#x298C;': '\\[',
    '&#x298B;': '\\]',
    '&#x298A;': '\\triangleright',
    '&#x2989;': '\\triangleleft',
    '&#x2988;': '|\\)',
    '&#x2987;': '\\(|',
    '&#x2986;': '|\\)',
    '&#x2985;': '\\(\\(',
    '&#x2984;': '|\\}',
    '&#x2983;': '\\{|',
    '&#x2980;': '\\||',
    '&#x27EF;': '\\left. \\right]',
    '&#x27EE;': '\\left[ \\right.',
    '&#x27ED;': '\\left. \\right]]',
    '&#x27EC;': '\\left[[ \\right.',
    '&#x27EB;': '\\gg',
    '&#x27EA;': '\\ll',
    '&#x27E9;': '\\rangle',
    '&#x27E8;': '\\langle',
    '&#x27E7;': '\\left. \\right]]',
    '&#x27E6;': '\\left[[ \\right.',
    '&#x2773;': '\\left.\\right)',
    '&#x2772;': '\\left(\\right.',
    '&#x232A;': '\\rangle',
    '&#x2329;': '\\langle',
    '&#x230B;': '\\rfloor',
    '&#x230A;': '\\lfloor',
    '&#x2309;': '\\rceil',
    '&#x2308;': '\\lceil',
    '&#x2016;': '\\parallel',
    '}': '\\left.\\right}',
    '{': '\\left{\\right.',
    ']': '\\left]\\right.',
    '[': '\\left[\\right.',
    ')': '\\left.\\right)',
    '(': '\\left(\\right.',
    '&#x201D;': '"',
    '&#x201C;': '``',
    '&#x2019;': "'",
    '&#x2018;': '`',
    '%CE%B1': '\\alpha',
    '%CE%B2': '\\beta',
    '%CE%B3': '\\gamma',
    '%CE%93': '\\Gamma',
    '%CE%B4': '\\delta',
    '%CE%94': '\\Delta',
    '%CF%B5': '\\epsilon',
    '%CE%B6': '\\zeta',
    '%CE%B7': '\\eta',
    '%CE%B8': '\\theta',
    '%CE%98': '\\Theta',
    '%CE%B9': '\\iota',
    '%CE%BA': '\\kappa',
    '%CE%BB': '\\lambda',
    '%CE%BC': '\\mu',
    '%CE%BD': '\\nu',
    '%CE%BF': '\\omicron',
    '%CF%80': '\\pi',
    '%CE%A0': '\\Pi',
    '%CF%81': '\\pho',
    '%CF%83': '\\sigma',
    '%CE%A3': '\\Sigma',
    '%CF%84': '\\tau',
    '%CF%85': '\\upsilon',
    '%CE%A5': '\\Upsilon',
    '%CF%95': '\\phi',
    '%CE%A6': '\\Phi',
    '%CF%87': '\\chi',
    '%CF%88': '\\psi',
    '%CE%A8': '\\Psi',
    '%CF%89': '\\omega',
    '%CE%A9': '\\Omega',
}

all_math_operators_by_glyph = {
  '_': '\\underline',
  '⏡': '\\underbrace',
  '⏠': '\\overbrace',
  '⏟': '\\underbrace',
  '⏞': '\\overbrace',
  '⏝': '\\underbrace',
  '⏜': '\\overbrace',
  '⎵': '\\underbrace',
  '⎴': '\\overbrace',
  '⃜': '\\square',
  '⃛': '\\square',
  '⁤': '',
  '⁗': "''''",
  '‾': '\\overline',
  '‷': '```',
  '‶': '``',
  '‵': '`',
  '‴': "'''",
  '″': "''",
  '‟': '``',
  '„': ',,',
  '‛': '`',
  '‚': ',',
  '^': '\\hat',
  '˷': '\\sim',
  '˝': '\\sim',
  '˜': '\\sim',
  '˚': '\\circ',
  '˙': '\\cdot',
  '˘': ' ',
  'ˍ': '\\_',
  'ˋ': 'ˋ',
  'ˊ': 'ˊ',
  'ˉ': 'ˉ',
  'ˇ': '',
  'ˆ': '\\hat',
  'º': 'o',
  '¹': '1',
  '¸': ',',
  '´': '´',
  '³': '3',
  '²': '2',
  '°': '\\circ',
  '¯': '\\bar',
  'ª': 'a',
  '↛': '\\nrightarrow',
  '¨': '\\cdot\\cdot',
  '~': '\\sim',
  '`': '`',
  '--': '--',
  '++': '++',
  '&': '\\&',
  '∜': '\\sqrt[4]{}',
  '∛': '\\sqrt[3]{}',
  '√': '\\sqrt{}',
  'ⅆ': 'd',
  'ⅅ': '\\mathbb{D}',
  '?': '?',
  '@': '@',
  '//': '//',
  '!!': '!!',
  '!': '!',
  '♯': '\\#',
  '♮': '',
  '♭': '',
  '′': "'",
  '<>': '<>',
  '**': '\\star\\star',
  '∇': '\\nabla',
  '∂': '\\partial',
  '⊙': '\\bigodot',
  '¬': '\\neg',
  '∢': '\\measuredangle',
  '∡': '\\measuredangle',
  '∠': '\\angle',
  '÷': '\\div',
  '/': '/',
  '∖': '\\backslash',
  '\\': '\\backslash',
  '%': '\\%',
  '⊗': '\\bigotimes',
  '·': '\\cdot',
  '⨿': '\\coprod',
  '⨯': '\\times',
  '⋅': '\\cdot',
  '⊡': '\\boxdot',
  '⊠': '\\boxtimes',
  '⁢': '',
  '⁃': '-',
  '•': '\\cdot',
  '.': '.',
  '*': '\\star',
  '∪': '\\cup',
  '∩': '\\cap',
  '∐': '\\coprod',
  '∏': '\\prod',
  '≀': '',
  '⫿': '',
  '⫼': '\\mid\\mid\\mid',
  '⨉': '\\times',
  '⨈': '',
  '⨇': '',
  '⨆': '\\sqcup',
  '⨅': '\\sqcap',
  '⨂': '\\otimes',
  '⨀': '\\odot',
  '⋂': '\\cap',
  '⋁': '\\vee',
  '⋀': '\\wedge',
  '⨄': '\\uplus',
  '⨃': '\\cup',
  '⋃': '\\cup',
  '⨜': '\\underline{\\int}',
  '⨛': '\\overline{\\int}',
  '⨚': '\\int',
  '⨙': '\\int',
  '⨘': '\\int',
  '⨗': '\\int',
  '⨖': '\\oint',
  '⨕': '\\oint',
  '⨔': '\\int',
  '⨓': '\\int',
  '⨒': '\\int',
  '⨑': '\\int',
  '⨐': '\\int',
  '⨏': '\\bcancel{\\int}',
  '⨎': '',
  '⨍': '\\hcancel{\\int}',
  '⨌': '\\iiiint',
  '∳': '\\oint',
  '∲': '\\oint',
  '∱': '\\int',
  '∰': '\\oiint',
  '∯': '\\oiint',
  '∮': '\\oint',
  '∫': '\\int',
  '⨁': '\\oplus',
  '⊘': '\\oslash',
  '⊖': '\\ominus',
  '⊕': '\\oplus',
  '∭': '\\iiint',
  '∬': '\\iint',
  '⨋': '',
  '⨊': '',
  '∑': '\\sum',
  '⊟': '\\boxminus',
  '⊞': '\\boxplus',
  '∔': '\\dot{+}',
  '∓': '+-',
  '−': '-',
  '±': '\\pm',
  '-': '-',
  '+': '+',
  '⭆': '\\Rrightarrow',
  '⭅': '\\Lleftarrow',
  '⧴': ':\\rightarrow',
  '⧯': '',
  '⧟': '\\bullet-\\bullet',
  '⦟': '\\angle',
  '⦞': '\\measuredangle',
  '⦝': '\\measuredangle',
  '⦜': '\\perp',
  '⦛': '\\measuredangle',
  '⦚': '',
  '⦙': '\\vdots',
  '⥿': '',
  '⥾': '',
  '⥽': '\\prec',
  '⥼': '\\succ',
  '⥻': '\\underset{\\rightarrow}{\\supset}',
  '⥺': '',
  '⥹': '\\underset{\\rightarrow}{\\subset}',
  '⥸': '\\underset{\\rightarrow}{>}',
  '⥷': '',
  '⥶': '\\underset{\\leftarrow}{<}',
  '⥵': '\\underset{\\approx}{\\rightarrow}',
  '⥴': '\\underset{\\sim}{\\rightarrow}',
  '⥳': '\\underset{\\sim}{\\leftarrow}',
  '⥲': '\\overset{\\sim}{\\rightarrow}',
  '⥱': '\\overset{=}{\\rightarrow}',
  '⥰': '',
  '⥯': '',
  '⥮': '',
  '⥭': '\\overline{\\rightharpoondown}',
  '⥬': '\\underline{\\rightharpoonup}',
  '⥫': '\\overline{\\leftharpoondown}',
  '⥪': '\\underline{\\leftharpoonup}',
  '⥩': '\\rightleftharpoons',
  '⥨': '\\rightleftharpoons',
  '⥧': '\\rightleftharpoons',
  '⥦': '\\rightleftharpoons',
  '⥥': '\\Downarrow',
  '⥤': '\\Rightarrow',
  '⥣': '\\Uparrow',
  '⥢': '\\Leftarrow',
  '⥡': '\\downarrow',
  '⥠': '\\uparrow',
  '⥟': '\\rightarrow',
  '⥞': '\\leftarrow',
  '⥝': '\\downarrow',
  '⥜': '\\uparrow',
  '⥛': '\\rightarrow',
  '⥚': '\\leftarrow',
  '⥙': '\\downarrow',
  '⥘': '\\uparrow',
  '⥗': '\\rightarrow',
  '⥖': '\\leftarrow',
  '⥕': '\\downarrow',
  '⥔': '\\uparrow',
  '⥓': '\\rightarrow',
  '⥒': '\\leftarrow',
  '⥑': '\\updownarrow',
  '⥐': '\\leftrightarrow',
  '⥏': '\\updownarrow',
  '⥎': '\\leftrightarrow',
  '⥍': '\\updownarrow',
  '⥌': '\\updownarrow',
  '⥋': '\\leftrightarrow',
  '⥊': '\\leftrightarrow',
  '⥉': '',
  '⥈': '\\leftrightarrow',
  '⥇': '\\nrightarrow',
  '⥆': '',
  '⥅': '',
  '⥄': '\\rightleftarrows',
  '⥃': '\\leftrightarrows',
  '⥂': '\\rightleftarrows',
  '⥁': '\\circlearrowright',
  '⥀': '\\circlearrowleft',
  '⤿': '\\rightarrow',
  '⤾': '\\leftarrow',
  '⤽': '\\leftarrow',
  '⤼': '\\rightarrow',
  '⤻': '\\rightarrow',
  '⤺': '\\leftarrow',
  '⤹': '\\downarrow',
  '⤸': '\\downarrow',
  '⤷': '\\Rsh',
  '⤶': '\\Lsh',
  '⤵': '\\downarrow',
  '⤴': '\\uparrow',
  '⤳': '\\rightarrow',
  '⤲': '\\leftarrow',
  '⤱': ' ',
  '⤰': ' ',
  '⤯': ' ',
  '⤮': ' ',
  '⤭': ' ',
  '⤬': '\\times',
  '⤫': '\\times',
  '⤪': ' ',
  '⤩': ' ',
  '⤨': ' ',
  '⤧': ' ',
  '⤦': ' ',
  '⤥': ' ',
  '⤤': ' ',
  '⤣': ' ',
  '⤢': ' ',
  '⤡': ' ',
  '⤠': '\\mapsto\\cdot',
  '⤟': '\\cdot\\leftarrow',
  '⤞': '\\rightarrow\\cdot',
  '⤝': '\\leftarrow',
  '⤜': '\\rightarrow',
  '⤛': '\\leftarrow',
  '⤚': '\\rightarrow',
  '⤙': '\\leftarrow',
  '⤘': '\\rightarrow',
  '⤗': '\\rightarrow',
  '⤖': '\\rightarrow',
  '⤕': '\\rightarrow',
  '⤔': '\\rightarrow',
  '⤓': '\\downarrow',
  '⤒': '\\uparrow',
  '⤑': '\\rightarrow',
  '⤐': '\\rightarrow',
  '⤏': '\\rightarrow',
  '⤎': '\\leftarrow',
  '⤍': '\\rightarrow',
  '⤌': '\\leftarrow',
  '⤋': '\\Downarrow',
  '⤊': '\\Uparrow',
  '⤉': '\\uparrow',
  '⤈': '\\downarrow',
  '⤇': '\\Rightarrow',
  '⤆': '\\Leftarrow',
  '⤅': '\\mapsto',
  '⤄': '\\nLeftrightarrow',
  '⤃': '\\nRightarrow',
  '⤂': '\\nLeftarrow',
  '⤁': '\\rightsquigarrow',
  '⤀': '\\rightsquigarrow',
  '⟿': '\\rightsquigarrow',
  '⟾': '\\Rightarrow',
  '⟽': '\\Leftarrow',
  '⟼': '\\mapsto',
  '⟻': '\\leftarrow',
  '⟺': '\\Longleftrightarrow',
  '⟹': '\\Longrightarrow',
  '⟸': '\\Longleftarrow',
  '⟷': '\\leftrightarrow',
  '⟶': '\\rightarrow',
  '⟵': '\\leftarrow',
  '⟱': '\\Downarrow',
  '⟰': '\\Uparrow',
  '⊸': '\\rightarrow',
  '⇿': '\\leftrightarrow',
  '⇾': '\\rightarrow',
  '⇽': '\\leftarrow',
  '⇼': '\\nleftrightarrow',
  '⇻': '\\nrightarrow',
  '⇺': '\\nleftarrow',
  '⇹': '\\nleftrightarrow',
  '⇸': '\\nrightarrow',
  '⇷': '\\nleftarrow',
  '⇶': '\\Rrightarrow',
  '⇵': '',
  '⇴': '\\rightarrow',
  '⇳': '\\Updownarrow',
  '⇲': '\\searrow',
  '⇱': '\\nwarrow',
  '⇰': '\\Leftarrow',
  '⇯': '\\Uparrow',
  '⇮': '\\Uparrow',
  '⇭': '\\Uparrow',
  '⇬': '\\Uparrow',
  '⇫': '\\Uparrow',
  '⇪': '\\Uparrow',
  '⇩': '\\Downarrow',
  '⇨': '\\Rightarrow',
  '⇧': '\\Uparrow',
  '⇦': '\\Leftarrow',
  '⇥': '\\rightarrow',
  '⇤': '\\leftarrow',
  '⇣': '\\downarrow',
  '⇢': '\\rightarrow',
  '⇡': '\\uparrow',
  '⇠': '\\leftarrow',
  '⇟': '\\downarrow',
  '⇞': '\\uparrow',
  '⇝': '\\rightsquigarrow',
  '⇜': '\\leftarrow',
  '⇛': '\\Rrightarrow',
  '⇚': '\\Lleftarrow',
  '⇙': '\\swarrow',
  '⇘': '\\searrow',
  '⇗': '\\nearrow',
  '⇖': '\\nwarrow',
  '⇕': '\\Updownarrow',
  '⇔': '\\Leftrightarrow',
  '⇓': '\\Downarrow',
  '⇒': '\\Rightarrow',
  '⇑': '\\Uparrow',
  '⇐': '\\Leftarrow',
  '⇏': '\\nRightarrow',
  '⇎': '\\nLeftrightarrow',
  '⇍': '\\nLeftarrow',
  '⇌': '\\rightleftharpoons',
  '⇋': '\\leftrightharpoons',
  '⇊': '\\downdownarrows',
  '⇉': '\\rightrightarrows',
  '⇈': '\\upuparrows',
  '⇇': '\\leftleftarrows',
  '⇆': '\\leftrightarrows',
  '⇅': '',
  '⇄': '\\rightleftarrows',
  '⇃': '\\downharpoonleft',
  '⇂': '\\downharpoonright',
  '⇁': '\\rightharpoondown',
  '⇀': '\\rightharpoonup',
  '↿': '\\upharpoonleft',
  '↾': '\\upharpoonright',
  '↽': '\\leftharpoondown',
  '↼': '\\leftharpoonup',
  '↻': '\\circlearrowright',
  '↺': '\\circlearrowleft',
  '↹': '\\leftrightarrows',
  '↸': '\\overline{\\nwarrow}',
  '↷': '\\curvearrowright',
  '↶': '\\curvearrowleft',
  '↵': '\\swarrow',
  '↴': '\\searrow',
  '↳': '\\Rsh',
  '↲': '\\Lsh',
  '↱': '\\Rsh',
  '↰': '\\Lsh',
  '↯': '\\swarrow',
  '↮': '',
  '↭': '\\leftrightsquigarrow',
  '↬': '\\looparrowright',
  '↫': '\\looparrowleft',
  '↪': '\\hookrightarrow',
  '↩': '\\hookleftarrow',
  '↨': '\\underline{\\updownarrow}',
  '↧': '\\downarrow',
  '↦': '\\rightarrowtail',
  '↥': '\\uparrow',
  '↤': '\\leftarrowtail',
  '↣': '\\rightarrowtail',
  '↢': '\\leftarrowtail',
  '↡': '\\downarrow',
  '↠': '\\twoheadrightarrow',
  '↟': '\\uparrow',
  '↞': '\\twoheadleftarrow',
  '↝': '\\nearrow',
  '↜': '\\nwarrow',
  '↚': '',
  '↙': '\\swarrow',
  '↘': '\\searrow',
  '↗': '\\nearrow',
  '↖': '\\nwarrow',
  '↕': '\\updownarrow',
  '↔': '\\leftrightarrow',
  '↓': '\\downarrow',
  '→': '\\rightarrow',
  '↑': '\\uparrow',
  '←': '\\leftarrow',
  '|||': '\\left|||\\right.',
  '||': '\\left||\\right.',
  '|': '\\mid',
  '⫾': '',
  '⫽': '//',
  '⫻': '///',
  '⫺': '',
  '⫹': '',
  '⫸': '',
  '⫷': '',
  '⫶': '\\vdots',
  '⫵': '',
  '⫴': '',
  '⫳': '',
  '⫲': '\\nparallel',
  '⫱': '',
  '⫰': '',
  '⫯': '',
  '⫮': '\\bcancel{\\mid}',
  '⫭': '',
  '⫬': '',
  '⫫': '',
  '⫪': '',
  '⫩': '',
  '⫨': '\\underline{\\perp}',
  '⫧': '\\overline{\\top}',
  '⫦': '',
  '⫥': '',
  '⫤': '',
  '⫣': '',
  '⫢': '',
  '⫡': '',
  '⫠': '\\perp',
  '⫟': '\\top',
  '⫞': '\\dashv',
  '⫝̸': '',
  '⫝': '',
  '⫛': '\\pitchfork',
  '⫚': '',
  '⫙': '',
  '⫘': '',
  '⫗': '',
  '⫖': '',
  '⫕': '',
  '⫔': '',
  '⫓': '',
  '⫒': '',
  '⫑': '',
  '⫐': '',
  '⫏': '',
  '⫎': '',
  '⫍': '',
  '⫌': '\\underset{\\neq}{\\supset}',
  '⫋': '\\underset{\\neq}{\\subset}',
  '⫊': '\\underset{\\approx}{\\supset}',
  '⫉': '\\underset{\\approx}{\\subset}',
  '⫈': '\\underset{\\sim}{\\supset}',
  '⫇': '\\underset{\\sim}{\\subset}',
  '⫆': '\\supseteqq',
  '⫅': '\\subseteqq',
  '⫄': '\\dot{\\supseteq}',
  '⫃': '\\dot{\\subseteq}',
  '⫂': '\\underset{\\times}{\\supset}',
  '⫁': '\\underset{\\times}{\\subset}',
  '⫀': '\\underset{+}{\\supset}',
  '⪿': '\\underset{+}{\\subset}',
  '⪾': '',
  '⪽': '',
  '⪼': '\\gg ',
  '⪻': '\\ll',
  '⪺': '\\underset{\\cancel{\\approx}}{\\succ}',
  '⪹': '\\underset{\\cancel{\\approx}}{\\prec}',
  '⪸': '\\underset{\\approx}{\\succ}',
  '⪷': '\\underset{\\approx}{\\prec}',
  '⪶': '\\underset{\\cancel{=}}{\\succ}',
  '⪵': '\\underset{\\cancel{=}}{\\prec}',
  '⪴': '\\underset{=}{\\succ}',
  '⪳': '\\underset{=}{\\prec}',
  '⪲': '',
  '⪱': '',
  '⪮': '',
  '⪭': '\\underline{\\hcancel{>}}',
  '⪬': '\\underline{\\hcancel{>}}',
  '⪫': '\\hcancel{>}',
  '⪪': '\\hcancel{<}',
  '⪩': '',
  '⪨': '',
  '⪧': '\\vartriangleright',
  '⪦': '\\vartriangleleft',
  '⪥': '><',
  '⪤': '><',
  '⪣': '\\underline{\\ll}',
  '⪢̸': '\\cancel{\\gg}',
  '⪢': '\\gg',
  '⪡̸': '\\cancel{\\ll}',
  '⪡': '\\ll',
  '⪠': '\\overset{\\sim}{\\geqq}',
  '⪟': '\\overset{\\sim}{\\leqq}',
  '⪞': '\\overset{\\sim}{>}',
  '⪝': '\\overset{\\sim}{<}',
  '⪜': '',
  '⪛': '',
  '⪚': '\\overset{=}{>}',
  '⪙': '\\overset{=}{<}',
  '⪘': '',
  '⪗': '',
  '⪖': '',
  '⪕': '',
  '⪔': '',
  '⪓': '',
  '⪒': '\\underset{=}{\\gtrless}',
  '⪑': '\\underset{=}{\\lessgtr}',
  '⪐': '\\underset{<}{\\gtrsim}',
  '⪏': '\\underset{>}{\\lesssim}',
  '⪎': '\\underset{\\simeq}{>}',
  '⪍': '\\underset{\\simeq}{<}',
  '⪌': '\\gtreqqless',
  '⪋': '\\lesseqqgtr',
  '⪊': '\\underset{\\cancel{\\approx}}{>}',
  '⪉': '\\underset{\\approx}{<}',
  '⪆': '\\underset{\\approx}{>}',
  '⪅': '\\underset{\\approx}{<}',
  '⪄': '',
  '⪃': '',
  '⪂': '',
  '⪁': '',
  '⪀': '',
  '⩿': '',
  '⩾̸': '\\bcancel{\\geq}',
  '⩾': '\\geq',
  '⩽̸': '\\bcancel{\\leq}',
  '⩽': '\\leq',
  '⩼': '',
  '⩻': '',
  '⩺': '',
  '⩹': '',
  '⩸': '\\overset{\\dots}{\\equiv}',
  '⩷': '',
  '⩶': '===',
  '⩵': '==',
  '⩴': '::=',
  '⩳': '',
  '⩲': '\\underset{=}{+}',
  '⩱': '\\overset{=}{+}',
  '⩰': '\\overset{\\approx}{=}',
  '⩯': '\\overset{\\wedge}{=}',
  '⩮': '\\overset{*}{=}',
  '⩭': '\\dot{\\approx}',
  '⩬': '',
  '⩫': '',
  '⩪': '\\dot{\\sim}',
  '⩩': '',
  '⩨': '',
  '⩧': '\\dot{\\equiv}',
  '⩦': '\\underset{\\cdot}{=}',
  '⩥': '',
  '⩤': '',
  '⩣': '\\underset{=}{\\vee}',
  '⩢': '\\overset{=}{\\vee}',
  '⩡': 'ul(vv)',
  '⩠': '\\underset{=}{\\wedge}',
  '⩟': '\\underline{\\wedge}',
  '⩞': '\\overset{=}{\\wedge}',
  '⩝': '\\hcancel{\\vee}',
  '⩜': '\\hcancel{\\wedge}',
  '⩛': '',
  '⩚': '',
  '⩙': '',
  '⩘': '\\vee',
  '⩗': '\\wedge',
  '⩖': '',
  '⩕': '',
  '⩔': '',
  '⩓': '',
  '⩒': '\\dot{\\vee}',
  '⩑': '\\dot{\\wedge}',
  '⩐': '',
  '⩏': '',
  '⩎': '',
  '⩍': '\\overline{\\cap}',
  '⩌': '\\overline{\\cup}',
  '⩋': '',
  '⩊': '',
  '⩉': '',
  '⩈': '',
  '⩇': '',
  '⩆': '',
  '⩅': '',
  '⩄': '',
  '⩃': '\\overline{\\cap}',
  '⩂': '\\overline{\\cup}',
  '⩁': '',
  '⩀': '',
  '⨾': '',
  '⨽': '\\llcorner',
  '⨼': '\\lrcorner',
  '⨻': '',
  '⨺': '',
  '⨹': '',
  '⨸': '',
  '⨷': '',
  '⨶': '\\hat{\\otimes}',
  '⨵': '',
  '⨴': '',
  '⨳': '',
  '⨲': '\\underline{\\times}',
  '⨱': '\\underline{\\times}',
  '⨰': '\\dot{\\times}',
  '⨮': '\\bigodot',
  '⨭': '\\bigodot',
  '⨬': '',
  '⨫': '',
  '⨪': '',
  '⨩': '',
  '⨨': '',
  '⨧': '',
  '◻': '\\Box',
  '⨦': '\\underset{\\sim}{+}',
  '⨥': '\\underset{\\circ}{+}',
  '⨤': '\\overset{\\sim}{+}',
  '⨣': '\\hat{+}',
  '⨢': '\\dot{+}',
  '⨡': '\\upharpoonright',
  '⨠': '>>',
  '⨟': '',
  '⨞': '\\triangleleft',
  '⨝': '\\bowtie',
  '⧿': '',
  '⧾': '+',
  '⧻': '\\hcancel{|||}',
  '⧺': '\\hcancel{||}',
  '⧹': '\\backslash',
  '⧸': '/',
  '⧷': 'hcancel{\backslash}',
  '⧶': '',
  '⧵': '\\backslash',
  '⧲': '\\Phi',
  '⧱': '',
  '⧰': '',
  '⧮': '',
  '⧭': '',
  '⧬': '',
  '⧫': '\\lozenge',
  '⧪': '',
  '⧩': '',
  '⧨': '',
  '⧧': '\\ddagger',
  '⧢': '\\sqcup\\sqcup',
  '⧡': '',
  '⧠': '\\square',
  '⧞': '',
  '⧝': '',
  '⧜': '',
  '⧛': '\\{\\{',
  '⧙': '\\{',
  '⧘': '\\}',
  '⧗': '',
  '⧖': '',
  '⧕': '\\bowtie',
  '⧔': '\\bowtie',
  '⧓': '\\bowtie',
  '⧒': '\\bowtie',
  '⧑': '\\bowtie',
  '⧐̸': '| \\not\\triangleright',
  '⧐': '| \\triangleright',
  '⧏̸': '\\not\\triangleleft |',
  '⧏': '\\triangleleft |',
  '⧎': '',
  '⧍': '\\triangle',
  '⧌': '',
  '⧋': '\\underline{\\triangle}',
  '⧊': '\\dot{\\triangle}',
  '⧉': '',
  '⧈': '\\boxed{\\circ}',
  '⧇': '\\boxed{\\circ}',
  '⧆': '\\boxed{\\rightarrow}',
  '⧅': '\\bcancel{\\square}',
  '⧄': '\\cancel{\\square}',
  '⧃': '\\odot',
  '⧂': '\\odot',
  '⦿': '\\odot',
  '⦾': '\\odot',
  '⦽': '\\varnothing',
  '⦼': '\\oplus',
  '⦻': '\\otimes',
  '⦺': '',
  '⦹': '\\varnothing',
  '⦸': '\\varnothing',
  '⦷': '\\ominus',
  '⦶': '\\ominus',
  '⦵': '\\ominus',
  '⦴': '\\vec{\\varnothing}',
  '⦳': '\\vec{\\varnothing}',
  '⦲': '\\dot{\\varnothing}',
  '⦱': '\\overline{\\varnothing}',
  '⦰': '\\varnothing',
  '⦯': '\\measuredangle',
  '⦮': '\\measuredangle',
  '⦭': '\\measuredangle',
  '⦬': '\\measuredangle',
  '⦫': '\\measuredangle',
  '⦪': '\\measuredangle',
  '⦩': '\\measuredangle',
  '⦨': '\\measuredangle',
  '⦧': '',
  '⦦': '',
  '⦥': '',
  '⦤': '',
  '⦣': '\\ulcorner',
  '⦢': '\\measuredangle',
  '⦡': '\\not\\lor',
  '⦠': '\\bcancel{>}',
  '⦂': ':',
  '⦁': '\\cdot',
  '❘': '\\mid',
  '▲': '\\bigtriangleup',
  '⋿': '\\Epsilon',
  '⋾': '\\overline{\\ni}',
  '⋽': '\\overline{\\ni}',
  '⋼': '\\in',
  '⋻': '\\in',
  '⋺': '\\in',
  '⋹': '\\underline{\\in}',
  '⋸': '\\underline{\\in}',
  '⋷': '\\overline{\\in}',
  '⋶': '\\overline{\\in}',
  '⋵': '\\dot{\\in}',
  '⋴': '\\in',
  '⋳': '\\in',
  '⋲': '\\in',
  '⋰': '\\ddots',
  '։': ':',
  '⋩': '\\underset{\\sim}{\\succ}',
  '⋨': '\\underset{\\sim}{\\prec}',
  '⋧': '\\underset{\\not\\sim}{>}',
  '⋦': '\\underset{\\not\\sim}{<}',
  '⋥': '\\not\\sqsupseteq',
  '⋤': '\\not\\sqsubseteq',
  '⋣': '\\not\\sqsupseteq',
  '⋢': '\\not\\sqsubseteq',
  '⋡': '\\nsucc',
  '⋠': '\\nprec',
  '⋟': '\\succ',
  '⋞': '\\prec',
  '⋝': '\\overline{>}',
  '⋜': '\\overline{<}',
  '⋛': '\\underset{>}{\\leq}',
  '⋚': '\\underset{<}{\\geq}',
  '⋕': '\\#',
  '⋓': '\\cup',
  '⋒': '\\cap',
  '⋑': '\\supset',
  '⋐': '\\subset',
  '⋏': '\\wedge',
  '⋎': '\\vee',
  '⋍': '\\simeq',
  '⋈': '\\Join',
  '⋇': '\\ast',
  '⋆': '\\star',
  '⋄': '\\diamond',
  '⊿': '\\triangle',
  '⊾': '\\measuredangle',
  '⊽': '\\overline{\\lor}',
  '⊼': '\\overline{\\land}',
  '⊻': '\\underline{\\lor}',
  '⊺': '\\top',
  '土': '\\pm',
  '十': '+',
  '⊹': '',
  '⊷': '\\circ\\multimap',
  '⊶': '\\circ\\multimap',
  '⊳': '\\triangleright',
  '⊲': '\\triangleleft',
  '⊱': '\\succ',
  '⊰': '\\prec',
  '⊫': '|\\models',
  '⊪': '|\\models',
  '⊧': '\\models',
  '⊦': '\\vdash',
  '⊝': '\\ominus',
  '⊜': '\\ominus',
  '⊛': '\\odot',
  '⊚': '\\odot',
  '⊔': '\\sqcup',
  '⊓': '\\sqcap',
  '⊒': '\\sqsupseteq',
  '⊑': '\\sqsubseteq',
  '⊐̸': '\\not\\sqsupset',
  '⊐': '\\sqsupset',
  '⊏̸': '\\not\\sqsubset',
  '⊏': '\\sqsubset',
  '⊎': '\\cup',
  '⊍': '\\cup',
  '⊌': '\\cup',
  '≿̸': '\\not\\succsim',
  '≿': '\\succsim',
  '≾': '\\precsim',
  '≹': '\\not\\overset{>}{<}',
  '≸': '\\not\\overset{>}{<}',
  '≷': '\\overset{>}{<}',
  '≶': '\\overset{<}{>}',
  '≵': '\\not\\geg',
  '≴': '\\not\\leq',
  '≳': '\\geg',
  '≲': '\\leq',
  '≬': '',
  '≧': '\\geg',
  '≦̸': '\\not\\leq',
  '≦': '\\leq',
  '≣': '\\overset{=}{=} ',
  '≞': '\\overset{m}{=} ',
  '≝': '\\overset{def}{=}',
  '≘': '=',
  '≖': '=',
  '≕': '=:',
  '≓': '\\doteq',
  '≒': '\\doteq',
  '≑': '\\doteq',
  '≐': '\\doteq',
  '≏̸': '',
  '≏': '',
  '≎̸': '',
  '≎': '',
  '≌': '\\approx',
  '≋': '\\approx',
  '≊': '\\approx',
  '≂̸': '\\neq',
  '≂': '=',
  '∿': '\\sim',
  '∾': '\\infty',
  '∽̱': '\\sim',
  '∽': '\\sim',
  '∻': '\\sim',
  '∺': ':-:',
  '∹': '-:',
  '∸': '\\bot',
  '∷': '::',
  '∶': ':',
  '∣': '\\mid',
  '∟': '\\llcorner',
  '∘': '\\circ',
  '∗': '*',
  '∕': '/',
  '∎': '\\square',
  '∍': '\\ni',
  '∊': '\\in',
  '∆': '\\Delta',
  '⁄': '/',
  '⪰̸': '\\nsucceq',
  '⪰': '\\succeq',
  '⪯̸': '\\npreceq',
  '⪯': '\\preceq',
  '⪈': '\\ngeqslant',
  '⪇': '\\nleqslant',
  '⧳': '\\Phi',
  '⧦': '\\models',
  '⧥': '\\not\\equiv',
  '⧤': '\\approx\\neq',
  '⧣': '\\neq',
  '⧁': '\\circle',
  '⧀': '\\circle',
  '◦': '\\circle',
  '◗': '\\circle',
  '◖': '\\circle',
  '●': '\\circle',
  '◎': '\\circledcirc',
  '◍': '\\circledcirc',
  '◌': '\\circledcirc',
  '◉': '\\circledcirc',
  '◈': '\\diamond',
  '◇': '\\diamond',
  '◆': '\\diamond',
  '◅': '\\triangleleft',
  '◄': '\\triangleleft',
  '◃': '\\triangleleft',
  '◂': '\\triangleleft',
  '◁': '\\triangleleft',
  '◀': '\\triangleleft',
  '▿': '\\triangledown',
  '▾': '\\triangledown',
  '▽': '\\triangledown',
  '▼': '\\triangledown',
  '▹': '\\triangleright',
  '▸': '\\triangleright',
  '▷': '\\triangleright',
  '▶': '\\triangleright',
  '▵': '\\triangle',
  '▴': '\\triangle',
  '△': '\\triangle',
  '▱': '\\square',
  '▰': '\\blacksquare',
  '▯': '\\square',
  '▮': '\\blacksquare',
  '▭': '\\square',
  '▫': '\\square',
  '▪': '\\square',
  '□': '\\square',
  '■': '\\blacksquare',
  '⋭': '\\not\\triangleright',
  '⋬': '\\not\\triangleleft',
  '⋫': '\\not\\triangleright',
  '⋪': '\\not\\triangleleft',
  '⋙': '\\ggg',
  '⋘': '\\lll',
  '⋗': '*>',
  '⋖': '<*',
  '⋔': '\\pitchfork',
  '⋌': '',
  '⋋': '\\bowtie',
  '⋊': '\\ltimes',
  '⋉': '\\rtimes',
  '⊵': '\\triangleright',
  '\\triangleleft': '',
  '⊥': '\\bot',
  '⊁': '\\nsucc',
  '⊀': '\\preceq',
  '≽': '\\succeq',
  '≼': '\\preceq',
  '≻': '\\succ',
  '≺': '\\prec',
  '≱': '\\geq/',
  '≰': '\\leq/',
  '≭': '\\neq',
  '≫̸': '\\not\\gg',
  '≫': '\\gg',
  '≪̸': '\\not\\ll',
  '≪': '\\ll',
  '≩': '\\ngeqslant',
  '≨': '\\nleqslant',
  '≡': '\\equiv',
  '≟': '\\doteq',
  '≜': '\\triangleq',
  '≛': '\\doteq',
  '≚': '\\triangleq',
  '≙': '\\triangleq',
  '≗': '\\doteq',
  '≔': ':=',
  '≍': '\\asymp',
  '≇': '\\ncong',
  '≆': '\\ncong',
  '≅': '\\cong',
  '≄': '\\not\\simeq',
  '≃': '\\simeq',
  '≁': '\\not\\sim',
  '∦': '\\not\\parallel',
  '∥': '\\parallel',
  '∤': '\\not|',
  '∝': '\\propto',
  '==': '==',
  '=': '=',
  ':=': ':=',
  '/=': '=',
  '-=': '-=',
  '+=': '+=',
  '*=': '*=',
  '!=': '!=',
  '≠': '\\neq',
  '≢': '\\equiv /',
  '≉': '\\approx /',
  '∼': 'sim',
  '≈': '\\approx',
  '≮': '</',
  '<': '<',
  '≯': '>/',
  '>=': '>=',
  '>': '>',
  '≥': '\\geq',
  '≤': '\\leq',
  '<=': '<=',
  '⊋': '\\supsetneq',
  '⊊': '\\subsetneq',
  '⊉': '\\nsupseteq',
  '⊈': '\\nsubseteq',
  '⊇': '\\supseteq',
  '⊆': '\\subseteq',
  '⊅': '\\not\\supset',
  '⊄': '\\not\\subset',
  '⊃⃒': '\\supset |',
  '⊃': '\\supset',
  '⊂⃒': '\\subset |',
  '⊂': '\\subset',
  '∌': '\\not\\in',
  '∉': '\\notin',
  '∈': '\\in',
  '∁': 'C',
  '∄': '\\nexists',
  '∃': '\\exists',
  '∀': '\\forall',
  '∧': '\\land',
  '&&': '\\&\\&',
  '∨': '\\lor',
  '⊯': '\\cancel{\\vDash}',
  '⊮': '\\cancel{\\Vdash}',
  '⊭': '\\nvDash',
  '⊬': '\\nvDash',
  '⊩': '\\Vdash',
  '⊨': '\\vDash',
  '⊤': '\\top',
  '⊣': '\\dashv',
  '⊢': '\\vdash',
  '∋': '\\ni',
  '⋱': '\\ddots',
  '⋯': '\\hdots',
  '⋮': '\\vdots',
  '϶': '\\ni',
  ':': ':',
  '...': '\\cdots',
  '..': '..',
  '->': '->',
  '∵': '\\because',
  '∴': '\\therefore ',
  '⁣': '\\llbracket',
  ',': ',',
  ';': ';',
  '⧽': '\\}',
  '⧼': '\\{',
  '⦘': '\\]',
  '⦗': '\\[',
  '⦖': '\\ll',
  '⦕': '\\gg',
  '⦔': '\\gg',
  '⦓': '\\ll',
  '⦒': '\\gg',
  '⦑': '\\ll',
  '⦐': '\\]',
  '⦏': '\\]',
  '⦎': '\\]',
  '⦍': '\\[',
  '⦌': '\\[',
  '⦋': '\\]',
  '⦊': '\\triangleright',
  '⦉': '\\triangleleft',
  '⦈': '|\\)',
  '⦇': '\\(|',
  '⦆': '|\\)',
  '⦅': '\\(\\(',
  '⦄': '|\\}',
  '⦃': '\\{|',
  '⦀': '\\||',
  '⟯': '\\left. \\right]',
  '⟮': '\\left[ \\right.',
  '⟭': '\\left. \\right]]',
  '⟬': '\\left[[ \\right.',
  '⟫': '\\gg',
  '⟪': '\\ll',
  '⟧': '\\)|',
  '⟦': '\\(|',
  '❳': '\\left.\\right)',
  '❲': '\\left(\\right.',
  '〉': '\\rangle',
  '〈': '\\langle',
  '⌋': '\\rfloor',
  '⌊': '\\lfloor',
  '⌉': '\\rceil',
  '⌈': '\\lceil',
  '‖': '\\parallel',
  '}': '\\left.\\right}',
  '{': '\\left{\\right.',
  ']': '\\left]\\right.',
  '[': '\\left[\\right.',
  ')': '\\left.\\right)',
  '(': '\\left(\\right.',
  '”': '\\"',
  '“': '\\text{``}',
  '’': "'",
  '‘': '`',
  'α': '\\alpha',
  'β': '\\beta',
  'γ': '\\gamma',
  'Γ': '\\Gamma',
  'δ': '\\delta',
  'Δ': '\\Delta',
  'ϵ': '\\epsilon',
  'ζ': '\\zeta',
  'η': '\\eta',
  'θ': '\\theta',
  'Θ': '\\Theta',
  'ι': '\\iota',
  'κ': '\\kappa',
  'λ': '\\lambda',
  'ν': '\\nu',
  'ο': '\\omicron',
  'π': '\\pi',
  'Π': '\\Pi',
  'ρ': '\\rho',
  'σ': '\\sigma',
  'Σ': '\\Sigma',
  'τ': '\\tau',
  'υ': '\\upsilon',
  'Υ': '\\Upsilon',
  'ϕ': '\\phi',
  'Φ': '\\Phi',
  'χ': '\\chi',
  'ψ': '\\psi',
  'Ψ': '\\Psi',
  'ω': '\\omega',
  'Ω': '\\Omega',
  'Ω': '\\Omega',
  '∅': '\\emptyset',
  '⟲': '\\circlearrowleft',
  '⟳': '\\circlearrowright',
  '×': '\\times',
  '½': '\\dfrac{1}{2}',
  'μ': '\\mu',
  'Ө': '\\theta',
  '✓': '\\checkmark',
  '⟩': '\\rangle',
  '⟨': '\\langle',
  '¼': '\\dfrac{1}{4}',
  '…': '\\ldots',
  'ℏ': '\\hbar',
  'ℜ': '\\mathfrak{R}',
  'Ѳ': '\\theta',
  'Ø': '\\emptyset',
  'ϱ': '\\varrho',
  'ф': '\\phi',
  'ℇ': '\\varepsilon',
  'T': 'T',
  '∙': '\\cdot',
  'Ρ': 'P',
  '∞': '\\infty',
  'ᐁ': '\\nabla',
  'ƞ': '\\eta',
  '⁺': '^{+}',
  '⁻': '^{-}',
  '⁼': '^{=}',
  '⁽': '^{(}',
  '⁾': '^{)}',
  '〗': '\\)|',
  '〖': '\\langle',
  ';': ';',
  '൦': '\\circ',
  '┴': '\\perp',
  '✕': '\\times',
  '⎻': '-',
  '»': '\\gg',
  '⬆': '\\uparrow',
  '⬇': '\\downarrow',
  '⬅': '\\leftarrow',
  '➡': '\\rightarrow',
  '⎼': '-',
  '⎜': '\\mid',
  '⎥': '\\mid',
  'ħ': '\\hbar',
  '⮕': '\\rightarrow',
  '・': '\\cdot',
  '¦': '\\mid',
  '£': '\\pounds',
  '¥': '\\yen',
  '✗': '\\times',
  '✔': '\\checkmark',
  'ⁿ': '^{n}',
  '«': '\\ll',
  'เ': '\\prime',
  '†': '\\dagger',
  '│': '\\mid',
  '$': '\\$',
  '#': '\\#',
  '℃': '\\text{\\textdegree C}',
  '℉': '\\text{\\textdegree F}',
  '█': '\\blacksquare',
  '℧': '\\mho',
  'ⅇ': '\\text{e}',
  'ɼ': 'r',
  '‡': '\\ddagger',
  'ἱ': 'i',
  'ϒ': '\\Upsilon',
  '𝛿': '\\delta',
  '˳': '\\cdot',
  'ѳ': '\\theta',
  '𝜙': '\\phi',
  'П': '\\prod',
  'о': 'o',
  'ђ': '\\hbar',
  'Ʌ': '\\Lambda',
  '।': '\\mid',
  '€': '\\euro',
  'ῡ': '\\bar{u}',
  'φ': '\\varphi',
  'ȼ': 'c',
  '𝞮': '\\epsilon',
  'Χ': '\\mathsf{X}',
  'ₙ': '_{n}',
}